summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorbala <balanatarajan@users.noreply.github.com>2001-03-29 23:55:37 +0000
committerbala <balanatarajan@users.noreply.github.com>2001-03-29 23:55:37 +0000
commita7d2ab6e2b47b16b31c8c043f5586206ee9b1fe1 (patch)
tree74f18587826204d21871d02572ac62af13c94edf
parent94613ee328d93496e9dcf992506a44ba1856e869 (diff)
downloadATCD-a7d2ab6e2b47b16b31c8c043f5586206ee9b1fe1.tar.gz
*** empty log message ***
-rw-r--r--TAO/tao/BiDir_GIOP/BiDirGIOP.cpp25
-rw-r--r--TAO/tao/BiDir_GIOP/BiDirGIOP.h6
-rw-r--r--TAO/tao/BiDir_GIOP/BiDir_Policy_i.cpp2
-rw-r--r--TAO/tao/BiDir_GIOP/BiDir_Policy_i.h2
-rw-r--r--TAO/tao/DynamicInterface/Context.h4
-rw-r--r--TAO/tao/DynamicInterface/DII_Invocation.cpp7
-rw-r--r--TAO/tao/DynamicInterface/ExceptionList.h7
-rw-r--r--TAO/tao/DynamicInterface/Request.cpp8
-rw-r--r--TAO/tao/ORB_Core.h8
-rw-r--r--TAO/tao/ORB_Core.i15
-rw-r--r--TAO/tao/PortableServer/Active_Object_Map.i37
-rw-r--r--TAO/tao/PortableServer/Makefile514
-rw-r--r--TAO/tao/PortableServer/MessagingS.cpp14
-rw-r--r--TAO/tao/PortableServer/MessagingS.h4
-rw-r--r--TAO/tao/PortableServer/Object_Adapter.cpp66
-rw-r--r--TAO/tao/PortableServer/Object_Adapter.h4
-rw-r--r--TAO/tao/PortableServer/POA.cpp104
-rw-r--r--TAO/tao/PortableServer/POA.h3
-rw-r--r--TAO/tao/PortableServer/POA.i3
-rw-r--r--TAO/tao/PortableServer/Servant_Base.i4
-rw-r--r--TAO/tao/PortableServer/ServerRequestInfo.cpp125
-rw-r--r--TAO/tao/PortableServer/ServerRequestInfo.h9
-rw-r--r--TAO/tao/PortableServer/Strategized_Object_Proxy_Broker.cpp14
-rw-r--r--TAO/tao/PortableServer/Strategized_Object_Proxy_Broker.h6
-rw-r--r--TAO/tao/Strategies/Direct_Priority_Mapping.cpp1
-rw-r--r--TAO/tao/Strategies/SHMIOP_Connection_Handler.cpp21
-rw-r--r--TAO/tao/Strategies/SHMIOP_Connector.cpp8
-rw-r--r--TAO/tao/Strategies/SHMIOP_Transport.cpp58
-rw-r--r--TAO/tao/Strategies/SHMIOP_Transport.h42
-rw-r--r--TAO/tao/Strategies/UIOP_Connection_Handler.cpp21
-rw-r--r--TAO/tao/Strategies/UIOP_Connector.cpp8
-rw-r--r--TAO/tao/Strategies/UIOP_Endpoint.cpp2
-rw-r--r--TAO/tao/Strategies/UIOP_Transport.cpp62
-rw-r--r--TAO/tao/Strategies/UIOP_Transport.h40
-rw-r--r--TAO/tao/Strategies/advanced_resource.cpp4
35 files changed, 608 insertions, 650 deletions
diff --git a/TAO/tao/BiDir_GIOP/BiDirGIOP.cpp b/TAO/tao/BiDir_GIOP/BiDirGIOP.cpp
index c088d27909a..4267d107e3d 100644
--- a/TAO/tao/BiDir_GIOP/BiDirGIOP.cpp
+++ b/TAO/tao/BiDir_GIOP/BiDirGIOP.cpp
@@ -44,6 +44,31 @@ TAO_BiDirGIOP_Loader::activate (CORBA::ORB_ptr,
}
int
+TAO_BiDirGIOP_Loader::parse_policy (TAO_ORB_Core *orb_core,
+ CORBA::Policy_ptr policy,
+ CORBA::Environment &ACE_TRY_ENV)
+{
+
+ BiDirPolicy::BidirectionalPolicy_var bidir_policy
+ = BiDirPolicy::BidirectionalPolicy::_narrow (policy,
+ ACE_TRY_ENV);
+ ACE_CHECK_RETURN (0);
+
+ // Bidirectional policy. If we have a BiDirectional policy, we set a
+ // flag in the ORB_Core for use by the ORB
+ if (!CORBA::is_nil (bidir_policy.in ()))
+ {
+ // Set the flag in the ORB_Core
+ if (bidir_policy->value () == BiDirPolicy::BOTH)
+ orb_core_->bidir_giop_policy (1);
+ return 1;
+ }
+
+ return 0;
+}
+
+
+int
TAO_BiDirGIOP_Loader::Initializer (void)
{
ACE_Service_Config::static_svcs ()->
diff --git a/TAO/tao/BiDir_GIOP/BiDirGIOP.h b/TAO/tao/BiDir_GIOP/BiDirGIOP.h
index e65a23d8871..f1957a828fd 100644
--- a/TAO/tao/BiDir_GIOP/BiDirGIOP.h
+++ b/TAO/tao/BiDir_GIOP/BiDirGIOP.h
@@ -38,6 +38,12 @@ public:
CORBA::Environment &ACE_TRY_ENV)
ACE_THROW_SPEC ((CORBA::SystemException));
+ /// Parse the policy sent by the ORB_Core
+ virtual int parse_policy (TAO_ORB_Core *orb_core,
+ CORBA::Policy_ptr policy,
+ CORBA::Environment &ACE_TRY_ENV)
+ ACE_THROW_SPEC ((CORBA::SystemException));
+
/// Used to force the initialization of the ORB code.
static int Initializer (void);
diff --git a/TAO/tao/BiDir_GIOP/BiDir_Policy_i.cpp b/TAO/tao/BiDir_GIOP/BiDir_Policy_i.cpp
index ebb928e17f8..1a9531c1c27 100644
--- a/TAO/tao/BiDir_GIOP/BiDir_Policy_i.cpp
+++ b/TAO/tao/BiDir_GIOP/BiDir_Policy_i.cpp
@@ -9,7 +9,7 @@ ACE_RCSID(TAO, BiDir_Policy_i, "$Id$")
#if ! defined (__ACE_INLINE__)
-#include "tao/BiDir_Policy_i.inl"
+#include "BiDir_Policy_i.inl"
#endif /* __ACE_INLINE__ */
TAO_BidirectionalPolicy::TAO_BidirectionalPolicy (
diff --git a/TAO/tao/BiDir_GIOP/BiDir_Policy_i.h b/TAO/tao/BiDir_GIOP/BiDir_Policy_i.h
index 6c5e31e581e..6b018cdc49e 100644
--- a/TAO/tao/BiDir_GIOP/BiDir_Policy_i.h
+++ b/TAO/tao/BiDir_GIOP/BiDir_Policy_i.h
@@ -88,7 +88,7 @@ private:
#if defined (__ACE_INLINE__)
-#include "tao/BiDir_Policy_i.inl"
+#include "BiDir_Policy_i.inl"
#endif /* __ACE_INLINE__ */
#if defined(_MSC_VER) && (_MSC_VER >= 1200)
diff --git a/TAO/tao/DynamicInterface/Context.h b/TAO/tao/DynamicInterface/Context.h
index 80142f84337..5d03f33a84f 100644
--- a/TAO/tao/DynamicInterface/Context.h
+++ b/TAO/tao/DynamicInterface/Context.h
@@ -21,14 +21,14 @@
#define TAO_CONTEXT_H
#include "ace/pre.h"
+#include "dynamicinterface_export.h"
#include "tao/corbafwd.h"
+#include "ace/Unbounded_Queue.h"
#if !defined (ACE_LACKS_PRAGMA_ONCE)
# pragma once
#endif /* ACE_LACKS_PRAGMA_ONCE */
-#include "dynamicinterface_export.h"
-
class TAO_DynamicInterface_Export CORBA_Context
{
// = TITLE
diff --git a/TAO/tao/DynamicInterface/DII_Invocation.cpp b/TAO/tao/DynamicInterface/DII_Invocation.cpp
index fe9cd11aaf1..c219b68d541 100644
--- a/TAO/tao/DynamicInterface/DII_Invocation.cpp
+++ b/TAO/tao/DynamicInterface/DII_Invocation.cpp
@@ -1,21 +1,20 @@
// $Id$
#include "DII_Invocation.h"
-
-ACE_RCSID(DynamicInterface, DII_Invocation, "$Id$")
-
#include "Unknown_User_Exception.h"
#include "tao/Stub.h"
#include "tao/Principal.h"
#include "tao/Object_KeyC.h"
#include "tao/Transport_Mux_Strategy.h"
-#include "tao/debug.h"
#include "tao/Transport.h"
#if !defined (__ACE_INLINE__)
# include "DII_Invocation.inl"
#endif /* ! __ACE_INLINE__ */
+ACE_RCSID(DynamicInterface, DII_Invocation, "$Id$")
+
+
int
TAO_GIOP_DII_Invocation::invoke (CORBA::ExceptionList_ptr exceptions,
CORBA::Environment &ACE_TRY_ENV)
diff --git a/TAO/tao/DynamicInterface/ExceptionList.h b/TAO/tao/DynamicInterface/ExceptionList.h
index 52d4a85758b..3f5115d7f21 100644
--- a/TAO/tao/DynamicInterface/ExceptionList.h
+++ b/TAO/tao/DynamicInterface/ExceptionList.h
@@ -11,7 +11,7 @@
// ExceptionList.h
//
// = DESCRIPTION
-// This file defines the ExceptionList datatype used in
+// This file defines the ExceptionList datatype used in
// dynamic invocations.
//
// = AUTHOR
@@ -23,14 +23,14 @@
#define TAO_CORBA_EXCEPTIONLIST_H
#include "ace/pre.h"
+#include "dynamicinterface_export.h"
#include "tao/corbafwd.h"
+#include "ace/Unbounded_Queue.h"
#if !defined (ACE_LACKS_PRAGMA_ONCE)
# pragma once
#endif /* ACE_LACKS_PRAGMA_ONCE */
-#include "dynamicinterface_export.h"
-
class CORBA_ExceptionList;
typedef CORBA_ExceptionList *CORBA_ExceptionList_ptr;
@@ -149,4 +149,3 @@ private:
#include "ace/post.h"
#endif /* TAO_CORBA_EXCEPTIONLIST_H */
-
diff --git a/TAO/tao/DynamicInterface/Request.cpp b/TAO/tao/DynamicInterface/Request.cpp
index aa261099450..cd05ee27d04 100644
--- a/TAO/tao/DynamicInterface/Request.cpp
+++ b/TAO/tao/DynamicInterface/Request.cpp
@@ -65,12 +65,12 @@ CORBA_Request::CORBA_Request (CORBA::Object_ptr obj,
CORBA::NamedValue_ptr result,
CORBA::Flags flags,
CORBA::ExceptionList_ptr exceptions,
- CORBA::Environment &ACE_TRY_ENV)
+ CORBA::Environment &env)
: orb_ (CORBA::ORB::_duplicate (orb)),
args_ (CORBA::NVList::_duplicate (args)),
result_ (CORBA::NamedValue::_duplicate (result)),
flags_ (flags),
- env_ (ACE_TRY_ENV),
+ env_ (env),
exceptions_ (CORBA::ExceptionList::_duplicate (exceptions)),
contexts_ (0),
ctx_ (CORBA::Context::_nil ()),
@@ -95,10 +95,10 @@ CORBA_Request::CORBA_Request (CORBA::Object_ptr obj,
CORBA_Request::CORBA_Request (CORBA::Object_ptr obj,
CORBA::ORB_ptr orb,
const CORBA::Char *op,
- CORBA::Environment &ACE_TRY_ENV)
+ CORBA::Environment &env)
: orb_ (CORBA::ORB::_duplicate (orb)),
flags_ (0),
- env_ (ACE_TRY_ENV),
+ env_ (env),
contexts_ (0),
ctx_ (CORBA::Context::_nil ()),
refcount_ (1),
diff --git a/TAO/tao/ORB_Core.h b/TAO/tao/ORB_Core.h
index d90d949d01e..44b22f66af0 100644
--- a/TAO/tao/ORB_Core.h
+++ b/TAO/tao/ORB_Core.h
@@ -43,6 +43,7 @@
#include "RT_Policy_i.h"
#include "Protocols_Hooks.h"
+#include "BiDir_Adapter.h"
#include "ace/Hash_Map_Manager.h"
#include "ace/Thread_Manager.h"
@@ -81,7 +82,7 @@ class TAO_Client_Priority_Policy_Selector;
class TAO_Message_State_Factory;
class TAO_ServerRequest;
class TAO_Protocols_Hooks;
-class TAO_BiDir_Adapter;
+
#if (TAO_HAS_BUFFERING_CONSTRAINT_POLICY == 1)
@@ -834,6 +835,10 @@ public:
/// Return the underlying connection cache.
TAO_Transport_Cache_Manager &transport_cache (void);
+ /// Call the bidir_giop library to parse the policy.
+ int parse_bidir_policy (CORBA::Policy_ptr policy,
+ CORBA::Environment &ACE_TRY_ENV);
+
/// Set and Get methods to indicate whether a BiDir IIOP policy has
/// been set in the POA.
/// @note At present, the value will be true even if one of the POA's
@@ -842,7 +847,6 @@ public:
void bidir_giop_policy (CORBA::Boolean);
-
/// Return the table that maps object key/name to de-stringified
/// object reference. It is needed for supporting local objects in
/// the resolve_initial_references() mechanism.
diff --git a/TAO/tao/ORB_Core.i b/TAO/tao/ORB_Core.i
index b84892c001d..f2dd69907ef 100644
--- a/TAO/tao/ORB_Core.i
+++ b/TAO/tao/ORB_Core.i
@@ -28,6 +28,21 @@ TAO_ORB_Core::transport_cache (void)
return this->transport_cache_;
}
+ACE_INLINE int
+TAO_ORB_Core::parse_bidir_policy (CORBA::Policy_ptr policy,
+ CORBA::Environment &ACE_TRY_ENV)
+{
+ if (this->bidir_adapter_)
+ return this->bidir_adapter_->parse_policy (this,
+ policy,
+ ACE_TRY_ENV);
+ else
+ // @@ The BiDirectional library hasn't been loaded. What do we do?
+ // We are just returning an error which will be processd by the
+ // POA who requested us to parse the policy.
+ return 0;
+}
+
ACE_INLINE CORBA::Boolean
TAO_ORB_Core::bidir_giop_policy (void)
{
diff --git a/TAO/tao/PortableServer/Active_Object_Map.i b/TAO/tao/PortableServer/Active_Object_Map.i
index b0275d474ee..fab49985db8 100644
--- a/TAO/tao/PortableServer/Active_Object_Map.i
+++ b/TAO/tao/PortableServer/Active_Object_Map.i
@@ -142,11 +142,8 @@ TAO_Active_Object_Map::find_servant_using_system_id_and_user_id (const PortableS
ACE_INLINE int
TAO_Active_Object_Map::find_servant_and_system_id_using_user_id (const PortableServer::ObjectId &user_id,
- PortableServer::Servant &servant,
- PortableServer::ObjectId_out system_id,
- CORBA::Short &priority)
+ TAO_Active_Object_Map::Map_Entry *&entry)
{
- Map_Entry *entry = 0;
int result = this->user_id_map_->find (user_id,
entry);
@@ -156,16 +153,6 @@ TAO_Active_Object_Map::find_servant_and_system_id_using_user_id (const PortableS
result = -1;
else if (entry->servant_ == 0)
result = -1;
- else
- {
- result = this->id_hint_strategy_->system_id (system_id,
- *entry);
- if (result == 0)
- {
- servant = entry->servant_;
- priority = entry->priority_;
- }
- }
}
return result;
@@ -173,10 +160,26 @@ TAO_Active_Object_Map::find_servant_and_system_id_using_user_id (const PortableS
ACE_INLINE int
TAO_Active_Object_Map::find_servant_and_system_id_using_user_id (const PortableServer::ObjectId &user_id,
- TAO_Active_Object_Map::Map_Entry *&entry)
+ PortableServer::Servant &servant,
+ PortableServer::ObjectId_out system_id,
+ CORBA::Short &priority)
{
- return this->user_id_map_->find (user_id,
- entry);
+ Map_Entry *entry = 0;
+ int result = this->find_servant_and_system_id_using_user_id (user_id,
+ entry);
+
+ if (result == 0)
+ {
+ result = this->id_hint_strategy_->system_id (system_id,
+ *entry);
+ if (result == 0)
+ {
+ servant = entry->servant_;
+ priority = entry->priority_;
+ }
+ }
+
+ return result;
}
ACE_INLINE int
diff --git a/TAO/tao/PortableServer/Makefile b/TAO/tao/PortableServer/Makefile
index 54b1a5e3987..e56ef05afcd 100644
--- a/TAO/tao/PortableServer/Makefile
+++ b/TAO/tao/PortableServer/Makefile
@@ -191,7 +191,6 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/corbafwd.i RTPortableServerC.h \
PortableServerC.h $(TAO_ROOT)/tao/CurrentC.h \
$(TAO_ROOT)/tao/Object.h \
- $(TAO_ROOT)/tao/Abstract_Servant_Base.h \
$(TAO_ROOT)/tao/Object_Proxy_Broker.h \
$(TAO_ROOT)/tao/Object_Proxy_Impl.h \
$(TAO_ROOT)/tao/Object.i \
@@ -273,7 +272,9 @@ CPPFLAGS += -I$(TAO_ROOT)
$(ACE_ROOT)/ace/Active_Map_Manager_T.cpp \
$(ACE_ROOT)/ace/Map_T.i \
$(ACE_ROOT)/ace/Map_T.cpp Key_Adapters.i poa_macros.h \
- Servant_Base.h Servant_Base.i Active_Object_Map.h \
+ Servant_Base.h \
+ $(TAO_ROOT)/tao/Abstract_Servant_Base.h \
+ Servant_Base.i Active_Object_Map.h \
$(TAO_ROOT)/tao/Server_Strategy_Factory.h \
Active_Object_Map.i $(TAO_ROOT)/tao/Adapter.h \
$(TAO_ROOT)/tao/Adapter.i \
@@ -379,7 +380,6 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/corbafwd.i \
$(TAO_ROOT)/tao/CurrentC.h \
$(TAO_ROOT)/tao/Object.h \
- $(TAO_ROOT)/tao/Abstract_Servant_Base.h \
$(TAO_ROOT)/tao/Object_Proxy_Broker.h \
$(TAO_ROOT)/tao/Object_Proxy_Impl.h \
$(TAO_ROOT)/tao/Object.i \
@@ -461,7 +461,9 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/TimeBaseC.h \
$(TAO_ROOT)/tao/TimeBaseC.i \
$(TAO_ROOT)/tao/RTCORBAC.i RTPortableServerC.i \
- Servant_Base.h Servant_Base.i Active_Object_Map.h \
+ Servant_Base.h \
+ $(TAO_ROOT)/tao/Abstract_Servant_Base.h \
+ Servant_Base.i Active_Object_Map.h \
$(TAO_ROOT)/tao/Server_Strategy_Factory.h \
Active_Object_Map.i $(TAO_ROOT)/tao/Adapter.h \
$(TAO_ROOT)/tao/Adapter.i \
@@ -584,7 +586,6 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/corbafwd.i \
$(TAO_ROOT)/tao/CurrentC.h \
$(TAO_ROOT)/tao/Object.h \
- $(TAO_ROOT)/tao/Abstract_Servant_Base.h \
$(TAO_ROOT)/tao/Object_Proxy_Broker.h \
$(TAO_ROOT)/tao/Object_Proxy_Impl.h \
$(TAO_ROOT)/tao/Object.i \
@@ -721,7 +722,6 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/corbafwd.i \
$(TAO_ROOT)/tao/CurrentC.h \
$(TAO_ROOT)/tao/Object.h \
- $(TAO_ROOT)/tao/Abstract_Servant_Base.h \
$(TAO_ROOT)/tao/Object_Proxy_Broker.h \
$(TAO_ROOT)/tao/Object_Proxy_Impl.h \
$(TAO_ROOT)/tao/Object.i \
@@ -801,7 +801,9 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/TimeBaseC.h \
$(TAO_ROOT)/tao/TimeBaseC.i \
$(TAO_ROOT)/tao/RTCORBAC.i RTPortableServerC.i \
- Servant_Base.h Servant_Base.i Active_Object_Map.h \
+ Servant_Base.h \
+ $(TAO_ROOT)/tao/Abstract_Servant_Base.h \
+ Servant_Base.i Active_Object_Map.h \
$(TAO_ROOT)/tao/Server_Strategy_Factory.h \
Active_Object_Map.i $(TAO_ROOT)/tao/Adapter.h \
$(TAO_ROOT)/tao/Adapter.i \
@@ -880,6 +882,7 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/RT_Policy_i.h \
$(TAO_ROOT)/tao/RT_Policy_i.i \
$(TAO_ROOT)/tao/Protocols_Hooks.h \
+ $(TAO_ROOT)/tao/BiDir_Adapter.h \
$(ACE_ROOT)/ace/Thread_Manager.h \
$(ACE_ROOT)/ace/Singleton.h \
$(ACE_ROOT)/ace/Singleton.i \
@@ -901,10 +904,6 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/debug.h \
$(TAO_ROOT)/tao/Acceptor_Registry.h \
$(TAO_ROOT)/tao/Acceptor_Registry.i \
- $(TAO_ROOT)/tao/BiDir_Policy_i.h \
- $(TAO_ROOT)/tao/BiDirPolicyC.h \
- $(TAO_ROOT)/tao/BiDirPolicyC.i \
- $(TAO_ROOT)/tao/BiDir_Policy_i.inl \
Default_Acceptor_Filter.h \
$(TAO_ROOT)/tao/Acceptor_Filter.h \
$(TAO_ROOT)/tao/Acceptor_Filter.i \
@@ -1035,7 +1034,6 @@ CPPFLAGS += -I$(TAO_ROOT)
$(ACE_ROOT)/ace/CDR_Stream.i \
$(TAO_ROOT)/tao/CDR.i \
$(TAO_ROOT)/tao/Object.h \
- $(TAO_ROOT)/tao/Abstract_Servant_Base.h \
$(TAO_ROOT)/tao/Object_Proxy_Broker.h \
$(TAO_ROOT)/tao/Object_Proxy_Impl.h \
$(TAO_ROOT)/tao/Object.i \
@@ -1142,7 +1140,6 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/corbafwd.i \
$(TAO_ROOT)/tao/CurrentC.h \
$(TAO_ROOT)/tao/Object.h \
- $(TAO_ROOT)/tao/Abstract_Servant_Base.h \
$(TAO_ROOT)/tao/Object_Proxy_Broker.h \
$(TAO_ROOT)/tao/Object_Proxy_Impl.h \
$(TAO_ROOT)/tao/Object.i \
@@ -1224,7 +1221,9 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/TimeBaseC.h \
$(TAO_ROOT)/tao/TimeBaseC.i \
$(TAO_ROOT)/tao/RTCORBAC.i RTPortableServerC.i \
- Servant_Base.h Servant_Base.i Active_Object_Map.h \
+ Servant_Base.h \
+ $(TAO_ROOT)/tao/Abstract_Servant_Base.h \
+ Servant_Base.i Active_Object_Map.h \
$(TAO_ROOT)/tao/Server_Strategy_Factory.h \
Active_Object_Map.i $(TAO_ROOT)/tao/Adapter.h \
$(TAO_ROOT)/tao/Adapter.i \
@@ -1243,44 +1242,54 @@ CPPFLAGS += -I$(TAO_ROOT)
$(ACE_ROOT)/ace/Containers_T.cpp POA.i \
Strategized_Object_Proxy_Broker.h \
$(TAO_ROOT)/tao/corba.h \
- $(TAO_ROOT)/tao/ORB.h \
- $(TAO_ROOT)/tao/Services.h \
- $(TAO_ROOT)/tao/Services.i \
- $(TAO_ROOT)/tao/CORBA_String.h \
- $(TAO_ROOT)/tao/CORBA_String.inl \
- $(TAO_ROOT)/tao/ORB.i \
$(TAO_ROOT)/tao/NVList.h \
$(TAO_ROOT)/tao/NVList.i \
$(TAO_ROOT)/tao/Principal.h \
$(TAO_ROOT)/tao/OctetSeqC.h \
$(TAO_ROOT)/tao/OctetSeqC.i \
$(TAO_ROOT)/tao/Principal.i \
- $(TAO_ROOT)/tao/TAO_Server_Request.h \
- $(TAO_ROOT)/tao/Tagged_Profile.h \
- $(TAO_ROOT)/tao/GIOPC.h \
- $(TAO_ROOT)/tao/GIOPC.i \
- $(TAO_ROOT)/tao/Tagged_Profile.i \
+ $(TAO_ROOT)/tao/ORB.h \
+ $(TAO_ROOT)/tao/Services.h \
+ $(TAO_ROOT)/tao/Services.i \
+ $(TAO_ROOT)/tao/CORBA_String.h \
+ $(TAO_ROOT)/tao/CORBA_String.inl \
+ $(TAO_ROOT)/tao/ORB.i \
+ $(TAO_ROOT)/tao/BoundsC.h \
+ $(TAO_ROOT)/tao/BoundsC.i \
+ $(TAO_ROOT)/tao/ValueBase.h \
+ $(TAO_ROOT)/tao/ValueBase.i \
+ $(TAO_ROOT)/tao/ValueFactory.h \
+ $(TAO_ROOT)/tao/ValueFactory.i \
+ $(TAO_ROOT)/tao/DomainC.h \
+ $(TAO_ROOT)/tao/ClientRequestInfo.h \
+ $(TAO_ROOT)/tao/PortableInterceptorC.h \
+ $(TAO_ROOT)/tao/DynamicC.h \
+ $(TAO_ROOT)/tao/DynamicC.i \
+ $(TAO_ROOT)/tao/MessagingC.h \
+ $(TAO_ROOT)/tao/Remote_Object_Proxy_Impl.h \
+ $(TAO_ROOT)/tao/PollableC.h \
+ $(TAO_ROOT)/tao/PollableC.i \
+ $(TAO_ROOT)/tao/MessagingC.i \
+ $(TAO_ROOT)/tao/PortableInterceptorC.i \
+ $(TAO_ROOT)/tao/StringSeqC.h \
+ $(TAO_ROOT)/tao/StringSeqC.i \
$(TAO_ROOT)/tao/Service_Context.h \
$(TAO_ROOT)/tao/Service_Context.inl \
- $(TAO_ROOT)/tao/TAO_Server_Request.i \
- $(TAO_ROOT)/tao/Remote_Object_Proxy_Impl.h \
- $(TAO_ROOT)/tao/Stub.h \
- $(TAO_ROOT)/tao/Pluggable.h \
- $(TAO_ROOT)/tao/Pluggable.i \
- $(TAO_ROOT)/tao/MProfile.h \
- $(TAO_ROOT)/tao/Profile.h \
- $(TAO_ROOT)/tao/Tagged_Components.h \
- $(TAO_ROOT)/tao/CONV_FRAMEC.h \
- $(TAO_ROOT)/tao/CONV_FRAMEC.i \
- $(TAO_ROOT)/tao/Tagged_Components.i \
- $(TAO_ROOT)/tao/GIOP_Message_State.h \
- $(TAO_ROOT)/tao/GIOP_Message_State.i \
- $(TAO_ROOT)/tao/Profile.i \
- $(TAO_ROOT)/tao/MProfile.i \
+ $(TAO_ROOT)/tao/ClientRequestInfo.inl \
+ $(TAO_ROOT)/tao/DomainC.i \
+ $(TAO_ROOT)/tao/WrongTransactionC.h \
+ $(TAO_ROOT)/tao/ObjectIDList.h \
+ $(TAO_ROOT)/tao/ObjectIDList.i \
+ $(TAO_ROOT)/tao/PortableInterceptor.h \
+ $(TAO_ROOT)/tao/Interceptor_List.h \
+ $(TAO_ROOT)/tao/Interceptor_List.inl \
+ $(TAO_ROOT)/tao/PortableInterceptor.i \
$(TAO_ROOT)/tao/ORB_Core.h \
$(TAO_ROOT)/tao/Policy_Manager.h \
$(TAO_ROOT)/tao/Policy_Manager.i \
$(TAO_ROOT)/tao/Resource_Factory.h \
+ $(TAO_ROOT)/tao/Pluggable.h \
+ $(TAO_ROOT)/tao/Pluggable.i \
$(TAO_ROOT)/tao/Protocol_Factory.h \
$(TAO_ROOT)/tao/params.h \
$(TAO_ROOT)/tao/params.i \
@@ -1295,18 +1304,6 @@ CPPFLAGS += -I$(TAO_ROOT)
$(ACE_ROOT)/ace/Managed_Object.i \
$(ACE_ROOT)/ace/Managed_Object.cpp \
$(TAO_ROOT)/tao/PolicyFactory_Registry.h \
- $(TAO_ROOT)/tao/PortableInterceptorC.h \
- $(TAO_ROOT)/tao/DynamicC.h \
- $(TAO_ROOT)/tao/DynamicC.i \
- $(TAO_ROOT)/tao/MessagingC.h \
- $(TAO_ROOT)/tao/ValueBase.h \
- $(TAO_ROOT)/tao/ValueBase.i \
- $(TAO_ROOT)/tao/ValueFactory.h \
- $(TAO_ROOT)/tao/ValueFactory.i \
- $(TAO_ROOT)/tao/PollableC.h \
- $(TAO_ROOT)/tao/PollableC.i \
- $(TAO_ROOT)/tao/MessagingC.i \
- $(TAO_ROOT)/tao/PortableInterceptorC.i \
$(TAO_ROOT)/tao/Parser_Registry.h \
$(TAO_ROOT)/tao/Parser_Registry.i \
$(TAO_ROOT)/tao/Service_Callbacks.h \
@@ -1324,54 +1321,37 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/Cleanup_Func_Registry.h \
$(TAO_ROOT)/tao/Cleanup_Func_Registry.inl \
$(TAO_ROOT)/tao/Object_Ref_Table.h \
- $(TAO_ROOT)/tao/Interceptor_List.h \
- $(TAO_ROOT)/tao/Interceptor_List.inl \
$(TAO_ROOT)/tao/RT_Policy_i.h \
$(TAO_ROOT)/tao/RT_Policy_i.i \
$(TAO_ROOT)/tao/Protocols_Hooks.h \
+ $(TAO_ROOT)/tao/BiDir_Adapter.h \
$(ACE_ROOT)/ace/Thread_Manager.h \
$(ACE_ROOT)/ace/Singleton.h \
$(ACE_ROOT)/ace/Singleton.i \
$(ACE_ROOT)/ace/Singleton.cpp \
$(ACE_ROOT)/ace/Thread_Manager.i \
- $(TAO_ROOT)/tao/ORB_Core.i \
- $(TAO_ROOT)/tao/Stub.i \
- $(TAO_ROOT)/tao/debug.h \
- $(TAO_ROOT)/tao/Client_Strategy_Factory.h \
- $(TAO_ROOT)/tao/Invocation.h \
- $(TAO_ROOT)/tao/Synch_Reply_Dispatcher.h \
- $(TAO_ROOT)/tao/Reply_Dispatcher.h \
- $(TAO_ROOT)/tao/Reply_Dispatcher.i \
- $(TAO_ROOT)/tao/TAOC.h \
- $(TAO_ROOT)/tao/Priority_Mapping_Manager.h \
- $(TAO_ROOT)/tao/Priority_Mapping.h \
- $(TAO_ROOT)/tao/Priority_Mapping.i \
- $(TAO_ROOT)/tao/Priority_Mapping_Manager.i \
- $(TAO_ROOT)/tao/TAOC.i \
- $(TAO_ROOT)/tao/operation_details.h \
- $(TAO_ROOT)/tao/target_specification.h \
- $(TAO_ROOT)/tao/target_specification.i \
- $(TAO_ROOT)/tao/operation_details.i \
- $(TAO_ROOT)/tao/Invocation_Endpoint_Selectors.h \
- $(TAO_ROOT)/tao/Invocation_Endpoint_Selectors.i \
- $(TAO_ROOT)/tao/Invocation.i \
- $(TAO_ROOT)/tao/ObjectIDList.h \
- $(TAO_ROOT)/tao/ObjectIDList.i \
- $(TAO_ROOT)/tao/DomainC.h \
- $(TAO_ROOT)/tao/ClientRequestInfo.h \
- $(TAO_ROOT)/tao/StringSeqC.h \
- $(TAO_ROOT)/tao/StringSeqC.i \
- $(TAO_ROOT)/tao/ClientRequestInfo.inl \
- $(TAO_ROOT)/tao/DomainC.i \
- $(TAO_ROOT)/tao/WrongTransactionC.h \
- $(TAO_ROOT)/tao/BoundsC.h \
- $(TAO_ROOT)/tao/BoundsC.i \
- $(TAO_ROOT)/tao/PortableInterceptor.h \
- $(TAO_ROOT)/tao/PortableInterceptor.i \
- ServerRequestInfo.h ServerRequestInfo.inl \
- $(ACE_ROOT)/ace/Auto_Ptr.h \
+ $(TAO_ROOT)/tao/ORB_Core.i ServerRequestInfo.h \
+ ServerRequestInfo.inl $(ACE_ROOT)/ace/Auto_Ptr.h \
$(ACE_ROOT)/ace/Auto_Ptr.i \
$(ACE_ROOT)/ace/Auto_Ptr.cpp \
+ $(TAO_ROOT)/tao/TAO_Server_Request.h \
+ $(TAO_ROOT)/tao/Tagged_Profile.h \
+ $(TAO_ROOT)/tao/GIOPC.h \
+ $(TAO_ROOT)/tao/GIOPC.i \
+ $(TAO_ROOT)/tao/Tagged_Profile.i \
+ $(TAO_ROOT)/tao/TAO_Server_Request.i \
+ $(TAO_ROOT)/tao/Stub.h \
+ $(TAO_ROOT)/tao/MProfile.h \
+ $(TAO_ROOT)/tao/Profile.h \
+ $(TAO_ROOT)/tao/Tagged_Components.h \
+ $(TAO_ROOT)/tao/CONV_FRAMEC.h \
+ $(TAO_ROOT)/tao/CONV_FRAMEC.i \
+ $(TAO_ROOT)/tao/Tagged_Components.i \
+ $(TAO_ROOT)/tao/GIOP_Message_State.h \
+ $(TAO_ROOT)/tao/GIOP_Message_State.i \
+ $(TAO_ROOT)/tao/Profile.i \
+ $(TAO_ROOT)/tao/MProfile.i \
+ $(TAO_ROOT)/tao/Stub.i \
$(TAO_ROOT)/tao/Timeprobe.h \
$(ACE_ROOT)/ace/Timeprobe.h
@@ -1536,7 +1516,6 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/PolicyC.h \
$(TAO_ROOT)/tao/CurrentC.h \
$(TAO_ROOT)/tao/Object.h \
- $(TAO_ROOT)/tao/Abstract_Servant_Base.h \
$(TAO_ROOT)/tao/Object_Proxy_Broker.h \
$(TAO_ROOT)/tao/Object_Proxy_Impl.h \
$(TAO_ROOT)/tao/Object.i \
@@ -1650,7 +1629,6 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/corbafwd.i \
$(TAO_ROOT)/tao/CurrentC.h \
$(TAO_ROOT)/tao/Object.h \
- $(TAO_ROOT)/tao/Abstract_Servant_Base.h \
$(TAO_ROOT)/tao/Object_Proxy_Broker.h \
$(TAO_ROOT)/tao/Object_Proxy_Impl.h \
$(TAO_ROOT)/tao/Object.i \
@@ -1826,7 +1804,6 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/corbafwd.i \
$(TAO_ROOT)/tao/CurrentC.h \
$(TAO_ROOT)/tao/Object.h \
- $(TAO_ROOT)/tao/Abstract_Servant_Base.h \
$(TAO_ROOT)/tao/Object_Proxy_Broker.h \
$(TAO_ROOT)/tao/Object_Proxy_Impl.h \
$(TAO_ROOT)/tao/Object.i \
@@ -1910,7 +1887,9 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/TimeBaseC.h \
$(TAO_ROOT)/tao/TimeBaseC.i \
$(TAO_ROOT)/tao/RTCORBAC.i RTPortableServerC.i \
- Servant_Base.h Servant_Base.i Active_Object_Map.h \
+ Servant_Base.h \
+ $(TAO_ROOT)/tao/Abstract_Servant_Base.h \
+ Servant_Base.i Active_Object_Map.h \
$(TAO_ROOT)/tao/Server_Strategy_Factory.h \
Active_Object_Map.i $(TAO_ROOT)/tao/Adapter.h \
$(TAO_ROOT)/tao/Adapter.i Object_Adapter.i \
@@ -2024,7 +2003,6 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/corbafwd.i \
$(TAO_ROOT)/tao/CurrentC.h \
$(TAO_ROOT)/tao/Object.h \
- $(TAO_ROOT)/tao/Abstract_Servant_Base.h \
$(TAO_ROOT)/tao/Object_Proxy_Broker.h \
$(TAO_ROOT)/tao/Object_Proxy_Impl.h \
$(TAO_ROOT)/tao/Object.i \
@@ -2100,7 +2078,9 @@ CPPFLAGS += -I$(TAO_ROOT)
$(ACE_ROOT)/ace/Active_Map_Manager_T.cpp \
$(ACE_ROOT)/ace/Map_T.i \
$(ACE_ROOT)/ace/Map_T.cpp Key_Adapters.i \
- Servant_Base.h Servant_Base.i \
+ Servant_Base.h \
+ $(TAO_ROOT)/tao/Abstract_Servant_Base.h \
+ Servant_Base.i \
$(TAO_ROOT)/tao/Server_Strategy_Factory.h \
Active_Object_Map.i $(ACE_ROOT)/ace/Auto_Ptr.h \
$(ACE_ROOT)/ace/Auto_Ptr.i \
@@ -2205,7 +2185,6 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/corbafwd.i \
$(TAO_ROOT)/tao/CurrentC.h \
$(TAO_ROOT)/tao/Object.h \
- $(TAO_ROOT)/tao/Abstract_Servant_Base.h \
$(TAO_ROOT)/tao/Object_Proxy_Broker.h \
$(TAO_ROOT)/tao/Object_Proxy_Impl.h \
$(TAO_ROOT)/tao/Object.i \
@@ -2234,6 +2213,7 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/PolicyC.i \
$(TAO_ROOT)/tao/Any.h \
$(TAO_ROOT)/tao/Any.i PortableServerC.i \
+ $(TAO_ROOT)/tao/Abstract_Servant_Base.h \
Servant_Base.i POA.h Object_Adapter.h Key_Adapters.h \
$(ACE_ROOT)/ace/Map.h \
$(ACE_ROOT)/ace/Map_T.h \
@@ -2369,6 +2349,7 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/RT_Policy_i.h \
$(TAO_ROOT)/tao/RT_Policy_i.i \
$(TAO_ROOT)/tao/Protocols_Hooks.h \
+ $(TAO_ROOT)/tao/BiDir_Adapter.h \
$(ACE_ROOT)/ace/Thread_Manager.h \
$(ACE_ROOT)/ace/Singleton.h \
$(ACE_ROOT)/ace/Singleton.i \
@@ -2500,7 +2481,6 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/corbafwd.i \
$(TAO_ROOT)/tao/CurrentC.h \
$(TAO_ROOT)/tao/Object.h \
- $(TAO_ROOT)/tao/Abstract_Servant_Base.h \
$(TAO_ROOT)/tao/Object_Proxy_Broker.h \
$(TAO_ROOT)/tao/Object_Proxy_Impl.h \
$(TAO_ROOT)/tao/Object.i \
@@ -2580,7 +2560,9 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/TimeBaseC.h \
$(TAO_ROOT)/tao/TimeBaseC.i \
$(TAO_ROOT)/tao/RTCORBAC.i RTPortableServerC.i \
- Servant_Base.h Servant_Base.i Active_Object_Map.h \
+ Servant_Base.h \
+ $(TAO_ROOT)/tao/Abstract_Servant_Base.h \
+ Servant_Base.i Active_Object_Map.h \
$(TAO_ROOT)/tao/Server_Strategy_Factory.h \
Active_Object_Map.i $(TAO_ROOT)/tao/Adapter.h \
$(TAO_ROOT)/tao/Adapter.i \
@@ -2659,6 +2641,7 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/RT_Policy_i.h \
$(TAO_ROOT)/tao/RT_Policy_i.i \
$(TAO_ROOT)/tao/Protocols_Hooks.h \
+ $(TAO_ROOT)/tao/BiDir_Adapter.h \
$(ACE_ROOT)/ace/Thread_Manager.h \
$(ACE_ROOT)/ace/Singleton.h \
$(ACE_ROOT)/ace/Singleton.i \
@@ -2780,7 +2763,6 @@ CPPFLAGS += -I$(TAO_ROOT)
Key_Adapters.h PortableServerC.h \
$(TAO_ROOT)/tao/CurrentC.h \
$(TAO_ROOT)/tao/Object.h \
- $(TAO_ROOT)/tao/Abstract_Servant_Base.h \
$(TAO_ROOT)/tao/Object_Proxy_Broker.h \
$(TAO_ROOT)/tao/Object.i \
$(TAO_ROOT)/tao/CurrentC.i \
@@ -2861,7 +2843,9 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/TimeBaseC.h \
$(TAO_ROOT)/tao/TimeBaseC.i \
$(TAO_ROOT)/tao/RTCORBAC.i RTPortableServerC.i \
- Servant_Base.h Servant_Base.i Active_Object_Map.h \
+ Servant_Base.h \
+ $(TAO_ROOT)/tao/Abstract_Servant_Base.h \
+ Servant_Base.i Active_Object_Map.h \
$(TAO_ROOT)/tao/Server_Strategy_Factory.h \
Active_Object_Map.i $(TAO_ROOT)/tao/Adapter.h \
$(TAO_ROOT)/tao/Adapter.i \
@@ -2967,14 +2951,33 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/varbase.h \
$(TAO_ROOT)/tao/TAO_Export.h \
$(TAO_ROOT)/tao/corbafwd.i \
- $(TAO_ROOT)/tao/Environment.h \
- $(TAO_ROOT)/tao/Environment.i \
- $(TAO_ROOT)/tao/ORB.h \
+ $(TAO_ROOT)/tao/Typecode.h \
$(TAO_ROOT)/tao/Exception.h \
$(ACE_ROOT)/ace/SString.h \
$(ACE_ROOT)/ace/SString.i \
$(TAO_ROOT)/tao/Exception.i \
- $(TAO_ROOT)/tao/Services.h \
+ $(TAO_ROOT)/tao/Typecode.i \
+ $(TAO_ROOT)/tao/Any.h \
+ $(TAO_ROOT)/tao/CDR.h \
+ $(ACE_ROOT)/ace/CDR_Stream.h \
+ $(ACE_ROOT)/ace/CDR_Stream.i \
+ $(TAO_ROOT)/tao/CDR.i \
+ $(TAO_ROOT)/tao/Environment.h \
+ $(TAO_ROOT)/tao/Environment.i \
+ $(TAO_ROOT)/tao/Object.h \
+ $(TAO_ROOT)/tao/Object_Proxy_Broker.h \
+ $(TAO_ROOT)/tao/Object_Proxy_Impl.h \
+ $(TAO_ROOT)/tao/Object.i \
+ $(TAO_ROOT)/tao/Any.i \
+ $(TAO_ROOT)/tao/NVList.h \
+ $(ACE_ROOT)/ace/Unbounded_Queue.h \
+ $(ACE_ROOT)/ace/Unbounded_Queue.inl \
+ $(ACE_ROOT)/ace/Unbounded_Queue.cpp \
+ $(TAO_ROOT)/tao/NVList.i \
+ $(TAO_ROOT)/tao/LocalObject.h \
+ $(TAO_ROOT)/tao/LocalObject.i \
+ $(TAO_ROOT)/tao/Principal.h \
+ $(TAO_ROOT)/tao/OctetSeqC.h \
$(TAO_ROOT)/tao/Sequence.h \
$(TAO_ROOT)/tao/Managed_Types.h \
$(TAO_ROOT)/tao/Managed_Types.i \
@@ -2982,73 +2985,58 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/Sequence_T.h \
$(TAO_ROOT)/tao/Sequence_T.i \
$(TAO_ROOT)/tao/Sequence_T.cpp \
+ $(TAO_ROOT)/tao/OctetSeqC.i \
+ $(TAO_ROOT)/tao/Principal.i \
+ $(TAO_ROOT)/tao/ORB.h \
+ $(TAO_ROOT)/tao/Services.h \
$(TAO_ROOT)/tao/Services.i \
$(TAO_ROOT)/tao/CORBA_String.h \
$(TAO_ROOT)/tao/CORBA_String.inl \
$(TAO_ROOT)/tao/PolicyC.h \
$(TAO_ROOT)/tao/CurrentC.h \
- $(TAO_ROOT)/tao/Object.h \
- $(TAO_ROOT)/tao/Abstract_Servant_Base.h \
- $(TAO_ROOT)/tao/Object_Proxy_Broker.h \
- $(TAO_ROOT)/tao/Object_Proxy_Impl.h \
- $(TAO_ROOT)/tao/Object.i \
$(TAO_ROOT)/tao/CurrentC.i \
$(TAO_ROOT)/tao/Encodable.h \
- $(TAO_ROOT)/tao/CDR.h \
- $(ACE_ROOT)/ace/CDR_Stream.h \
- $(ACE_ROOT)/ace/CDR_Stream.i \
- $(TAO_ROOT)/tao/CDR.i \
- $(TAO_ROOT)/tao/Typecode.h \
- $(TAO_ROOT)/tao/Typecode.i \
$(TAO_ROOT)/tao/PolicyC.i \
$(TAO_ROOT)/tao/ORB.i \
- $(TAO_ROOT)/tao/Any.h \
- $(TAO_ROOT)/tao/Any.i \
- $(TAO_ROOT)/tao/NVList.h \
- $(ACE_ROOT)/ace/Containers_T.h \
- $(ACE_ROOT)/ace/Containers.h \
- $(ACE_ROOT)/ace/Containers.i \
- $(ACE_ROOT)/ace/Array_Base.h \
- $(ACE_ROOT)/ace/Array_Base.inl \
- $(ACE_ROOT)/ace/Array_Base.cpp \
- $(ACE_ROOT)/ace/Unbounded_Queue.h \
- $(ACE_ROOT)/ace/Unbounded_Queue.inl \
- $(ACE_ROOT)/ace/Unbounded_Queue.cpp \
- $(ACE_ROOT)/ace/Containers_T.i \
- $(ACE_ROOT)/ace/Containers_T.cpp \
- $(TAO_ROOT)/tao/NVList.i \
- $(TAO_ROOT)/tao/Principal.h \
- $(TAO_ROOT)/tao/OctetSeqC.h \
- $(TAO_ROOT)/tao/OctetSeqC.i \
- $(TAO_ROOT)/tao/Principal.i \
- $(TAO_ROOT)/tao/TAO_Server_Request.h \
- $(TAO_ROOT)/tao/Tagged_Profile.h \
+ $(TAO_ROOT)/tao/BoundsC.h \
+ $(TAO_ROOT)/tao/BoundsC.i \
+ $(TAO_ROOT)/tao/ValueBase.h \
+ $(TAO_ROOT)/tao/ValueBase.i \
+ $(TAO_ROOT)/tao/ValueFactory.h \
+ $(TAO_ROOT)/tao/ValueFactory.i \
+ $(TAO_ROOT)/tao/DomainC.h \
+ $(TAO_ROOT)/tao/ClientRequestInfo.h \
+ $(TAO_ROOT)/tao/PortableInterceptorC.h \
+ $(TAO_ROOT)/tao/DynamicC.h \
+ $(TAO_ROOT)/tao/DynamicC.i \
+ $(TAO_ROOT)/tao/MessagingC.h \
+ $(TAO_ROOT)/tao/Remote_Object_Proxy_Impl.h \
+ $(TAO_ROOT)/tao/TimeBaseC.h \
+ $(TAO_ROOT)/tao/TimeBaseC.i \
$(TAO_ROOT)/tao/IOPC.h \
$(TAO_ROOT)/tao/IOPC.i \
- $(TAO_ROOT)/tao/GIOPC.h \
- $(TAO_ROOT)/tao/Object_KeyC.h \
- $(TAO_ROOT)/tao/Object_KeyC.i \
- $(TAO_ROOT)/tao/GIOPC.i \
- $(TAO_ROOT)/tao/Tagged_Profile.i \
+ $(TAO_ROOT)/tao/PollableC.h \
+ $(TAO_ROOT)/tao/PollableC.i \
+ $(TAO_ROOT)/tao/MessagingC.i \
+ $(TAO_ROOT)/tao/PortableInterceptorC.i \
+ $(TAO_ROOT)/tao/StringSeqC.h \
+ $(TAO_ROOT)/tao/StringSeqC.i \
$(TAO_ROOT)/tao/Service_Context.h \
$(TAO_ROOT)/tao/Service_Context.inl \
- $(TAO_ROOT)/tao/TAO_Server_Request.i \
- $(TAO_ROOT)/tao/Remote_Object_Proxy_Impl.h \
- $(TAO_ROOT)/tao/LocalObject.h \
- $(TAO_ROOT)/tao/LocalObject.i \
- $(TAO_ROOT)/tao/Stub.h \
- $(TAO_ROOT)/tao/Pluggable.h \
- $(TAO_ROOT)/tao/Pluggable.i \
- $(TAO_ROOT)/tao/MProfile.h \
- $(TAO_ROOT)/tao/Profile.h \
- $(TAO_ROOT)/tao/Tagged_Components.h \
- $(TAO_ROOT)/tao/CONV_FRAMEC.h \
- $(TAO_ROOT)/tao/CONV_FRAMEC.i \
- $(TAO_ROOT)/tao/Tagged_Components.i \
- $(TAO_ROOT)/tao/GIOP_Message_State.h \
- $(TAO_ROOT)/tao/GIOP_Message_State.i \
- $(TAO_ROOT)/tao/Profile.i \
- $(TAO_ROOT)/tao/MProfile.i \
+ $(TAO_ROOT)/tao/ClientRequestInfo.inl \
+ $(TAO_ROOT)/tao/DomainC.i \
+ $(TAO_ROOT)/tao/WrongTransactionC.h \
+ $(TAO_ROOT)/tao/Object_KeyC.h \
+ $(TAO_ROOT)/tao/Object_KeyC.i \
+ $(TAO_ROOT)/tao/ObjectIDList.h \
+ $(TAO_ROOT)/tao/ObjectIDList.i \
+ $(TAO_ROOT)/tao/PortableInterceptor.h \
+ $(TAO_ROOT)/tao/Interceptor_List.h \
+ $(ACE_ROOT)/ace/Array_Base.h \
+ $(ACE_ROOT)/ace/Array_Base.inl \
+ $(ACE_ROOT)/ace/Array_Base.cpp \
+ $(TAO_ROOT)/tao/Interceptor_List.inl \
+ $(TAO_ROOT)/tao/PortableInterceptor.i \
$(TAO_ROOT)/tao/ORB_Core.h \
$(TAO_ROOT)/tao/Policy_Manager.h \
$(TAO_ROOT)/tao/Policy_Manager.i \
@@ -3057,6 +3045,8 @@ CPPFLAGS += -I$(TAO_ROOT)
$(ACE_ROOT)/ace/Shared_Object.h \
$(ACE_ROOT)/ace/Shared_Object.i \
$(ACE_ROOT)/ace/Service_Object.i \
+ $(TAO_ROOT)/tao/Pluggable.h \
+ $(TAO_ROOT)/tao/Pluggable.i \
$(TAO_ROOT)/tao/Protocol_Factory.h \
$(TAO_ROOT)/tao/params.h \
$(TAO_ROOT)/tao/params.i \
@@ -3073,20 +3063,6 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/Adapter.h \
$(TAO_ROOT)/tao/Adapter.i \
$(TAO_ROOT)/tao/PolicyFactory_Registry.h \
- $(TAO_ROOT)/tao/PortableInterceptorC.h \
- $(TAO_ROOT)/tao/DynamicC.h \
- $(TAO_ROOT)/tao/DynamicC.i \
- $(TAO_ROOT)/tao/MessagingC.h \
- $(TAO_ROOT)/tao/ValueBase.h \
- $(TAO_ROOT)/tao/ValueBase.i \
- $(TAO_ROOT)/tao/ValueFactory.h \
- $(TAO_ROOT)/tao/ValueFactory.i \
- $(TAO_ROOT)/tao/TimeBaseC.h \
- $(TAO_ROOT)/tao/TimeBaseC.i \
- $(TAO_ROOT)/tao/PollableC.h \
- $(TAO_ROOT)/tao/PollableC.i \
- $(TAO_ROOT)/tao/MessagingC.i \
- $(TAO_ROOT)/tao/PortableInterceptorC.i \
$(ACE_ROOT)/ace/Map_Manager.h \
$(ACE_ROOT)/ace/Map_Manager.i \
$(ACE_ROOT)/ace/Map_Manager.cpp \
@@ -3130,54 +3106,24 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/Cleanup_Func_Registry.h \
$(TAO_ROOT)/tao/Cleanup_Func_Registry.inl \
$(TAO_ROOT)/tao/Object_Ref_Table.h \
- $(TAO_ROOT)/tao/Interceptor_List.h \
- $(TAO_ROOT)/tao/Interceptor_List.inl \
$(TAO_ROOT)/tao/RT_Policy_i.h \
$(TAO_ROOT)/tao/RTCORBAC.h \
$(TAO_ROOT)/tao/RTCORBAC.i \
$(TAO_ROOT)/tao/RT_Policy_i.i \
$(TAO_ROOT)/tao/Protocols_Hooks.h \
+ $(TAO_ROOT)/tao/BiDir_Adapter.h \
$(ACE_ROOT)/ace/Hash_Map_Manager.h \
$(ACE_ROOT)/ace/Thread_Manager.h \
+ $(ACE_ROOT)/ace/Containers.h \
+ $(ACE_ROOT)/ace/Containers.i \
+ $(ACE_ROOT)/ace/Containers_T.h \
+ $(ACE_ROOT)/ace/Containers_T.i \
+ $(ACE_ROOT)/ace/Containers_T.cpp \
$(ACE_ROOT)/ace/Singleton.h \
$(ACE_ROOT)/ace/Singleton.i \
$(ACE_ROOT)/ace/Singleton.cpp \
$(ACE_ROOT)/ace/Thread_Manager.i \
$(TAO_ROOT)/tao/ORB_Core.i \
- $(TAO_ROOT)/tao/Stub.i \
- $(TAO_ROOT)/tao/debug.h \
- $(TAO_ROOT)/tao/Client_Strategy_Factory.h \
- $(TAO_ROOT)/tao/Server_Strategy_Factory.h \
- $(TAO_ROOT)/tao/Invocation.h \
- $(TAO_ROOT)/tao/Synch_Reply_Dispatcher.h \
- $(TAO_ROOT)/tao/Reply_Dispatcher.h \
- $(TAO_ROOT)/tao/Reply_Dispatcher.i \
- $(TAO_ROOT)/tao/TAOC.h \
- $(TAO_ROOT)/tao/Priority_Mapping_Manager.h \
- $(TAO_ROOT)/tao/Priority_Mapping.h \
- $(TAO_ROOT)/tao/Priority_Mapping.i \
- $(TAO_ROOT)/tao/Priority_Mapping_Manager.i \
- $(TAO_ROOT)/tao/TAOC.i \
- $(TAO_ROOT)/tao/operation_details.h \
- $(TAO_ROOT)/tao/target_specification.h \
- $(TAO_ROOT)/tao/target_specification.i \
- $(TAO_ROOT)/tao/operation_details.i \
- $(TAO_ROOT)/tao/Invocation_Endpoint_Selectors.h \
- $(TAO_ROOT)/tao/Invocation_Endpoint_Selectors.i \
- $(TAO_ROOT)/tao/Invocation.i \
- $(TAO_ROOT)/tao/ObjectIDList.h \
- $(TAO_ROOT)/tao/ObjectIDList.i \
- $(TAO_ROOT)/tao/DomainC.h \
- $(TAO_ROOT)/tao/ClientRequestInfo.h \
- $(TAO_ROOT)/tao/StringSeqC.h \
- $(TAO_ROOT)/tao/StringSeqC.i \
- $(TAO_ROOT)/tao/ClientRequestInfo.inl \
- $(TAO_ROOT)/tao/DomainC.i \
- $(TAO_ROOT)/tao/WrongTransactionC.h \
- $(TAO_ROOT)/tao/BoundsC.h \
- $(TAO_ROOT)/tao/BoundsC.i \
- $(TAO_ROOT)/tao/PortableInterceptor.h \
- $(TAO_ROOT)/tao/PortableInterceptor.i \
Direct_Object_Proxy_Impl.h ThruPOA_Object_Proxy_Impl.h
.obj/Collocated_Object.o .obj/Collocated_Object.so .shobj/Collocated_Object.o .shobj/Collocated_Object.so: Collocated_Object.cpp Collocated_Object.h \
@@ -3278,7 +3224,6 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/varbase.h \
$(TAO_ROOT)/tao/TAO_Export.h \
$(TAO_ROOT)/tao/corbafwd.i \
- $(TAO_ROOT)/tao/Abstract_Servant_Base.h \
$(TAO_ROOT)/tao/Object_Proxy_Broker.h \
$(TAO_ROOT)/tao/Object_Proxy_Impl.h \
$(TAO_ROOT)/tao/Object.i Servant_Base.h \
@@ -3308,6 +3253,7 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/PolicyC.i \
$(TAO_ROOT)/tao/Any.h \
$(TAO_ROOT)/tao/Any.i PortableServerC.i \
+ $(TAO_ROOT)/tao/Abstract_Servant_Base.h \
Servant_Base.i Collocated_Object.i Object_Adapter.h Key_Adapters.h \
$(ACE_ROOT)/ace/Map.h \
$(ACE_ROOT)/ace/Map_T.h \
@@ -3381,14 +3327,6 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/Pluggable.h \
$(TAO_ROOT)/tao/Pluggable.i \
$(TAO_ROOT)/tao/Protocol_Factory.h \
- $(ACE_ROOT)/ace/Containers_T.h \
- $(ACE_ROOT)/ace/Containers.h \
- $(ACE_ROOT)/ace/Containers.i \
- $(ACE_ROOT)/ace/Array_Base.h \
- $(ACE_ROOT)/ace/Array_Base.inl \
- $(ACE_ROOT)/ace/Array_Base.cpp \
- $(ACE_ROOT)/ace/Containers_T.i \
- $(ACE_ROOT)/ace/Containers_T.cpp \
$(TAO_ROOT)/tao/params.h \
$(TAO_ROOT)/tao/params.i \
$(TAO_ROOT)/tao/TAO_Singleton_Manager.h \
@@ -3430,6 +3368,9 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/Cache_Entries.inl \
$(TAO_ROOT)/tao/Transport_Cache_Manager.inl \
$(TAO_ROOT)/tao/Cleanup_Func_Registry.h \
+ $(ACE_ROOT)/ace/Array_Base.h \
+ $(ACE_ROOT)/ace/Array_Base.inl \
+ $(ACE_ROOT)/ace/Array_Base.cpp \
$(TAO_ROOT)/tao/Cleanup_Func_Registry.inl \
$(TAO_ROOT)/tao/Object_Ref_Table.h \
$(TAO_ROOT)/tao/Interceptor_List.h \
@@ -3437,7 +3378,13 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/RT_Policy_i.h \
$(TAO_ROOT)/tao/RT_Policy_i.i \
$(TAO_ROOT)/tao/Protocols_Hooks.h \
+ $(TAO_ROOT)/tao/BiDir_Adapter.h \
$(ACE_ROOT)/ace/Thread_Manager.h \
+ $(ACE_ROOT)/ace/Containers.h \
+ $(ACE_ROOT)/ace/Containers.i \
+ $(ACE_ROOT)/ace/Containers_T.h \
+ $(ACE_ROOT)/ace/Containers_T.i \
+ $(ACE_ROOT)/ace/Containers_T.cpp \
$(ACE_ROOT)/ace/Singleton.h \
$(ACE_ROOT)/ace/Singleton.i \
$(ACE_ROOT)/ace/Singleton.cpp \
@@ -3555,7 +3502,6 @@ CPPFLAGS += -I$(TAO_ROOT)
PortableServerC.h portableserver_export.h \
$(TAO_ROOT)/tao/CurrentC.h \
$(TAO_ROOT)/tao/Object.h \
- $(TAO_ROOT)/tao/Abstract_Servant_Base.h \
$(TAO_ROOT)/tao/Object_Proxy_Broker.h \
$(TAO_ROOT)/tao/Object_Proxy_Impl.h \
$(TAO_ROOT)/tao/Object.i \
@@ -3584,6 +3530,7 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/PolicyC.i \
$(TAO_ROOT)/tao/Any.h \
$(TAO_ROOT)/tao/Any.i PortableServerC.i \
+ $(TAO_ROOT)/tao/Abstract_Servant_Base.h \
Servant_Base.i ThruPOA_Object_Proxy_Impl.h Direct_Object_Proxy_Impl.h \
$(TAO_ROOT)/tao/ORB_Core.h \
$(TAO_ROOT)/tao/ORB.h \
@@ -3606,18 +3553,10 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/IOPC.i \
$(TAO_ROOT)/tao/Pluggable.i \
$(TAO_ROOT)/tao/Protocol_Factory.h \
- $(ACE_ROOT)/ace/Containers_T.h \
- $(ACE_ROOT)/ace/Containers.h \
- $(ACE_ROOT)/ace/Containers.i \
- $(ACE_ROOT)/ace/Array_Base.h \
- $(ACE_ROOT)/ace/Array_Base.inl \
- $(ACE_ROOT)/ace/Array_Base.cpp \
+ $(TAO_ROOT)/tao/params.h \
$(ACE_ROOT)/ace/Unbounded_Queue.h \
$(ACE_ROOT)/ace/Unbounded_Queue.inl \
$(ACE_ROOT)/ace/Unbounded_Queue.cpp \
- $(ACE_ROOT)/ace/Containers_T.i \
- $(ACE_ROOT)/ace/Containers_T.cpp \
- $(TAO_ROOT)/tao/params.h \
$(TAO_ROOT)/tao/params.i \
$(TAO_ROOT)/tao/TAO_Singleton_Manager.h \
$(TAO_ROOT)/tao/TAO_Singleton_Manager.inl \
@@ -3688,6 +3627,9 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/Cache_Entries.inl \
$(TAO_ROOT)/tao/Transport_Cache_Manager.inl \
$(TAO_ROOT)/tao/Cleanup_Func_Registry.h \
+ $(ACE_ROOT)/ace/Array_Base.h \
+ $(ACE_ROOT)/ace/Array_Base.inl \
+ $(ACE_ROOT)/ace/Array_Base.cpp \
$(TAO_ROOT)/tao/Cleanup_Func_Registry.inl \
$(TAO_ROOT)/tao/Object_Ref_Table.h \
$(TAO_ROOT)/tao/Interceptor_List.h \
@@ -3697,8 +3639,14 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/RTCORBAC.i \
$(TAO_ROOT)/tao/RT_Policy_i.i \
$(TAO_ROOT)/tao/Protocols_Hooks.h \
+ $(TAO_ROOT)/tao/BiDir_Adapter.h \
$(ACE_ROOT)/ace/Hash_Map_Manager.h \
$(ACE_ROOT)/ace/Thread_Manager.h \
+ $(ACE_ROOT)/ace/Containers.h \
+ $(ACE_ROOT)/ace/Containers.i \
+ $(ACE_ROOT)/ace/Containers_T.h \
+ $(ACE_ROOT)/ace/Containers_T.i \
+ $(ACE_ROOT)/ace/Containers_T.cpp \
$(ACE_ROOT)/ace/Singleton.h \
$(ACE_ROOT)/ace/Singleton.i \
$(ACE_ROOT)/ace/Singleton.cpp \
@@ -3708,39 +3656,8 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/ClientRequestInfo.h \
$(TAO_ROOT)/tao/StringSeqC.h \
$(TAO_ROOT)/tao/StringSeqC.i \
- $(TAO_ROOT)/tao/Invocation.h \
- $(TAO_ROOT)/tao/Stub.h \
- $(TAO_ROOT)/tao/MProfile.h \
- $(TAO_ROOT)/tao/Profile.h \
- $(TAO_ROOT)/tao/Tagged_Components.h \
- $(TAO_ROOT)/tao/CONV_FRAMEC.h \
- $(TAO_ROOT)/tao/CONV_FRAMEC.i \
- $(TAO_ROOT)/tao/Tagged_Components.i \
- $(TAO_ROOT)/tao/GIOP_Message_State.h \
- $(TAO_ROOT)/tao/GIOP_Message_State.i \
- $(TAO_ROOT)/tao/Profile.i \
- $(TAO_ROOT)/tao/MProfile.i \
- $(TAO_ROOT)/tao/Stub.i \
- $(TAO_ROOT)/tao/Synch_Reply_Dispatcher.h \
- $(TAO_ROOT)/tao/Reply_Dispatcher.h \
- $(TAO_ROOT)/tao/Reply_Dispatcher.i \
- $(TAO_ROOT)/tao/TAOC.h \
- $(TAO_ROOT)/tao/Priority_Mapping_Manager.h \
- $(TAO_ROOT)/tao/Priority_Mapping.h \
- $(TAO_ROOT)/tao/Priority_Mapping.i \
- $(TAO_ROOT)/tao/Priority_Mapping_Manager.i \
- $(TAO_ROOT)/tao/TAOC.i \
- $(TAO_ROOT)/tao/operation_details.h \
$(TAO_ROOT)/tao/Service_Context.h \
$(TAO_ROOT)/tao/Service_Context.inl \
- $(TAO_ROOT)/tao/target_specification.h \
- $(TAO_ROOT)/tao/Object_KeyC.h \
- $(TAO_ROOT)/tao/Object_KeyC.i \
- $(TAO_ROOT)/tao/target_specification.i \
- $(TAO_ROOT)/tao/operation_details.i \
- $(TAO_ROOT)/tao/Invocation_Endpoint_Selectors.h \
- $(TAO_ROOT)/tao/Invocation_Endpoint_Selectors.i \
- $(TAO_ROOT)/tao/Invocation.i \
$(TAO_ROOT)/tao/ClientRequestInfo.inl \
$(TAO_ROOT)/tao/DomainC.i Object_Adapter.h \
Key_Adapters.h $(ACE_ROOT)/ace/Map.h \
@@ -3762,11 +3679,25 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/TAO_Server_Request.h \
$(TAO_ROOT)/tao/Tagged_Profile.h \
$(TAO_ROOT)/tao/GIOPC.h \
+ $(TAO_ROOT)/tao/Object_KeyC.h \
+ $(TAO_ROOT)/tao/Object_KeyC.i \
$(TAO_ROOT)/tao/GIOPC.i \
$(TAO_ROOT)/tao/Tagged_Profile.i \
$(TAO_ROOT)/tao/OctetSeqC.h \
$(TAO_ROOT)/tao/OctetSeqC.i \
- $(TAO_ROOT)/tao/TAO_Server_Request.i
+ $(TAO_ROOT)/tao/TAO_Server_Request.i \
+ $(TAO_ROOT)/tao/Stub.h \
+ $(TAO_ROOT)/tao/MProfile.h \
+ $(TAO_ROOT)/tao/Profile.h \
+ $(TAO_ROOT)/tao/Tagged_Components.h \
+ $(TAO_ROOT)/tao/CONV_FRAMEC.h \
+ $(TAO_ROOT)/tao/CONV_FRAMEC.i \
+ $(TAO_ROOT)/tao/Tagged_Components.i \
+ $(TAO_ROOT)/tao/GIOP_Message_State.h \
+ $(TAO_ROOT)/tao/GIOP_Message_State.i \
+ $(TAO_ROOT)/tao/Profile.i \
+ $(TAO_ROOT)/tao/MProfile.i \
+ $(TAO_ROOT)/tao/Stub.i
.obj/ORB_Manager.o .obj/ORB_Manager.so .shobj/ORB_Manager.o .shobj/ORB_Manager.so: ORB_Manager.cpp ORB_Manager.h \
$(ACE_ROOT)/ace/pre.h PortableServer.h \
@@ -3867,7 +3798,6 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/corbafwd.i RTPortableServerC.h \
PortableServerC.h $(TAO_ROOT)/tao/CurrentC.h \
$(TAO_ROOT)/tao/Object.h \
- $(TAO_ROOT)/tao/Abstract_Servant_Base.h \
$(TAO_ROOT)/tao/Object_Proxy_Broker.h \
$(TAO_ROOT)/tao/Object_Proxy_Impl.h \
$(TAO_ROOT)/tao/Object.i \
@@ -4016,7 +3946,6 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/Environment.h \
$(TAO_ROOT)/tao/Environment.i \
$(TAO_ROOT)/tao/Object.h \
- $(TAO_ROOT)/tao/Abstract_Servant_Base.h \
$(TAO_ROOT)/tao/Object_Proxy_Broker.h \
$(TAO_ROOT)/tao/Object_Proxy_Impl.h \
$(TAO_ROOT)/tao/Object.i \
@@ -4170,7 +4099,6 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/varbase.h \
$(TAO_ROOT)/tao/TAO_Export.h \
$(TAO_ROOT)/tao/corbafwd.i \
- $(TAO_ROOT)/tao/Abstract_Servant_Base.h \
$(TAO_ROOT)/tao/Object_Proxy_Broker.h \
$(TAO_ROOT)/tao/Object_Proxy_Impl.h \
$(TAO_ROOT)/tao/Object.i \
@@ -4242,18 +4170,10 @@ CPPFLAGS += -I$(TAO_ROOT)
$(ACE_ROOT)/ace/Shared_Object.i \
$(ACE_ROOT)/ace/Service_Object.i \
$(TAO_ROOT)/tao/Protocol_Factory.h \
- $(ACE_ROOT)/ace/Containers_T.h \
- $(ACE_ROOT)/ace/Containers.h \
- $(ACE_ROOT)/ace/Containers.i \
- $(ACE_ROOT)/ace/Array_Base.h \
- $(ACE_ROOT)/ace/Array_Base.inl \
- $(ACE_ROOT)/ace/Array_Base.cpp \
+ $(TAO_ROOT)/tao/params.h \
$(ACE_ROOT)/ace/Unbounded_Queue.h \
$(ACE_ROOT)/ace/Unbounded_Queue.inl \
$(ACE_ROOT)/ace/Unbounded_Queue.cpp \
- $(ACE_ROOT)/ace/Containers_T.i \
- $(ACE_ROOT)/ace/Containers_T.cpp \
- $(TAO_ROOT)/tao/params.h \
$(TAO_ROOT)/tao/params.i \
$(TAO_ROOT)/tao/Adapter.h \
$(TAO_ROOT)/tao/Adapter.i \
@@ -4314,6 +4234,9 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/Cache_Entries.inl \
$(TAO_ROOT)/tao/Transport_Cache_Manager.inl \
$(TAO_ROOT)/tao/Cleanup_Func_Registry.h \
+ $(ACE_ROOT)/ace/Array_Base.h \
+ $(ACE_ROOT)/ace/Array_Base.inl \
+ $(ACE_ROOT)/ace/Array_Base.cpp \
$(TAO_ROOT)/tao/Cleanup_Func_Registry.inl \
$(TAO_ROOT)/tao/Object_Ref_Table.h \
$(TAO_ROOT)/tao/Interceptor_List.h \
@@ -4323,8 +4246,14 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/RTCORBAC.i \
$(TAO_ROOT)/tao/RT_Policy_i.i \
$(TAO_ROOT)/tao/Protocols_Hooks.h \
+ $(TAO_ROOT)/tao/BiDir_Adapter.h \
$(ACE_ROOT)/ace/Hash_Map_Manager.h \
$(ACE_ROOT)/ace/Thread_Manager.h \
+ $(ACE_ROOT)/ace/Containers.h \
+ $(ACE_ROOT)/ace/Containers.i \
+ $(ACE_ROOT)/ace/Containers_T.h \
+ $(ACE_ROOT)/ace/Containers_T.i \
+ $(ACE_ROOT)/ace/Containers_T.cpp \
$(ACE_ROOT)/ace/Singleton.h \
$(ACE_ROOT)/ace/Singleton.i \
$(ACE_ROOT)/ace/Singleton.cpp \
@@ -4453,7 +4382,6 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/varbase.h \
$(TAO_ROOT)/tao/TAO_Export.h \
$(TAO_ROOT)/tao/corbafwd.i \
- $(TAO_ROOT)/tao/Abstract_Servant_Base.h \
$(TAO_ROOT)/tao/Object_Proxy_Broker.h \
$(TAO_ROOT)/tao/Object_Proxy_Impl.h \
$(TAO_ROOT)/tao/Object.i \
@@ -4494,6 +4422,7 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/PolicyC.h \
$(TAO_ROOT)/tao/Encodable.h \
$(TAO_ROOT)/tao/PolicyC.i PortableServerC.i \
+ $(TAO_ROOT)/tao/Abstract_Servant_Base.h \
Servant_Base.i ImplRepoS_T.h ImplRepoS_T.i ImplRepoS_T.cpp \
ImplRepoS.i Operation_Table.h \
$(ACE_ROOT)/ace/Hash_Map_Manager.h \
@@ -4579,14 +4508,6 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/Policy_Manager.i \
$(TAO_ROOT)/tao/Resource_Factory.h \
$(TAO_ROOT)/tao/Protocol_Factory.h \
- $(ACE_ROOT)/ace/Containers_T.h \
- $(ACE_ROOT)/ace/Containers.h \
- $(ACE_ROOT)/ace/Containers.i \
- $(ACE_ROOT)/ace/Array_Base.h \
- $(ACE_ROOT)/ace/Array_Base.inl \
- $(ACE_ROOT)/ace/Array_Base.cpp \
- $(ACE_ROOT)/ace/Containers_T.i \
- $(ACE_ROOT)/ace/Containers_T.cpp \
$(TAO_ROOT)/tao/params.h \
$(TAO_ROOT)/tao/params.i \
$(TAO_ROOT)/tao/PolicyFactory_Registry.h \
@@ -4618,6 +4539,9 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/Cache_Entries.inl \
$(TAO_ROOT)/tao/Transport_Cache_Manager.inl \
$(TAO_ROOT)/tao/Cleanup_Func_Registry.h \
+ $(ACE_ROOT)/ace/Array_Base.h \
+ $(ACE_ROOT)/ace/Array_Base.inl \
+ $(ACE_ROOT)/ace/Array_Base.cpp \
$(TAO_ROOT)/tao/Cleanup_Func_Registry.inl \
$(TAO_ROOT)/tao/Object_Ref_Table.h \
$(TAO_ROOT)/tao/Interceptor_List.h \
@@ -4625,7 +4549,13 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/RT_Policy_i.h \
$(TAO_ROOT)/tao/RT_Policy_i.i \
$(TAO_ROOT)/tao/Protocols_Hooks.h \
+ $(TAO_ROOT)/tao/BiDir_Adapter.h \
$(ACE_ROOT)/ace/Thread_Manager.h \
+ $(ACE_ROOT)/ace/Containers.h \
+ $(ACE_ROOT)/ace/Containers.i \
+ $(ACE_ROOT)/ace/Containers_T.h \
+ $(ACE_ROOT)/ace/Containers_T.i \
+ $(ACE_ROOT)/ace/Containers_T.cpp \
$(ACE_ROOT)/ace/Singleton.h \
$(ACE_ROOT)/ace/Singleton.i \
$(ACE_ROOT)/ace/Singleton.cpp \
@@ -4764,7 +4694,6 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/PolicyC.h \
$(TAO_ROOT)/tao/CurrentC.h \
$(TAO_ROOT)/tao/Object.h \
- $(TAO_ROOT)/tao/Abstract_Servant_Base.h \
$(TAO_ROOT)/tao/Object_Proxy_Broker.h \
$(TAO_ROOT)/tao/Object_Proxy_Impl.h \
$(TAO_ROOT)/tao/Object.i \
@@ -4794,18 +4723,10 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/IOPC.i \
$(TAO_ROOT)/tao/Pluggable.i \
$(TAO_ROOT)/tao/Protocol_Factory.h \
- $(ACE_ROOT)/ace/Containers_T.h \
- $(ACE_ROOT)/ace/Containers.h \
- $(ACE_ROOT)/ace/Containers.i \
- $(ACE_ROOT)/ace/Array_Base.h \
- $(ACE_ROOT)/ace/Array_Base.inl \
- $(ACE_ROOT)/ace/Array_Base.cpp \
+ $(TAO_ROOT)/tao/params.h \
$(ACE_ROOT)/ace/Unbounded_Queue.h \
$(ACE_ROOT)/ace/Unbounded_Queue.inl \
$(ACE_ROOT)/ace/Unbounded_Queue.cpp \
- $(ACE_ROOT)/ace/Containers_T.i \
- $(ACE_ROOT)/ace/Containers_T.cpp \
- $(TAO_ROOT)/tao/params.h \
$(TAO_ROOT)/tao/params.i \
$(TAO_ROOT)/tao/TAO_Singleton_Manager.h \
$(TAO_ROOT)/tao/TAO_Singleton_Manager.inl \
@@ -4876,6 +4797,9 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/Cache_Entries.inl \
$(TAO_ROOT)/tao/Transport_Cache_Manager.inl \
$(TAO_ROOT)/tao/Cleanup_Func_Registry.h \
+ $(ACE_ROOT)/ace/Array_Base.h \
+ $(ACE_ROOT)/ace/Array_Base.inl \
+ $(ACE_ROOT)/ace/Array_Base.cpp \
$(TAO_ROOT)/tao/Cleanup_Func_Registry.inl \
$(TAO_ROOT)/tao/Object_Ref_Table.h \
$(TAO_ROOT)/tao/Interceptor_List.h \
@@ -4885,14 +4809,21 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/RTCORBAC.i \
$(TAO_ROOT)/tao/RT_Policy_i.i \
$(TAO_ROOT)/tao/Protocols_Hooks.h \
+ $(TAO_ROOT)/tao/BiDir_Adapter.h \
$(ACE_ROOT)/ace/Hash_Map_Manager.h \
$(ACE_ROOT)/ace/Thread_Manager.h \
+ $(ACE_ROOT)/ace/Containers.h \
+ $(ACE_ROOT)/ace/Containers.i \
+ $(ACE_ROOT)/ace/Containers_T.h \
+ $(ACE_ROOT)/ace/Containers_T.i \
+ $(ACE_ROOT)/ace/Containers_T.cpp \
$(ACE_ROOT)/ace/Singleton.h \
$(ACE_ROOT)/ace/Singleton.i \
$(ACE_ROOT)/ace/Singleton.cpp \
$(ACE_ROOT)/ace/Thread_Manager.i \
$(TAO_ROOT)/tao/ORB_Core.i PortableServerC.h \
portableserver_export.h PortableServerC.i Servant_Base.h \
+ $(TAO_ROOT)/tao/Abstract_Servant_Base.h \
Servant_Base.i Collocated_Object.h Collocated_Object.i \
$(TAO_ROOT)/tao/TimeBaseS.h \
$(TAO_ROOT)/tao/TimeBaseS_T.h \
@@ -5058,7 +4989,6 @@ CPPFLAGS += -I$(TAO_ROOT)
$(TAO_ROOT)/tao/Environment.h \
$(TAO_ROOT)/tao/Environment.i \
$(TAO_ROOT)/tao/Object.h \
- $(TAO_ROOT)/tao/Abstract_Servant_Base.h \
$(TAO_ROOT)/tao/Object_Proxy_Broker.h \
$(TAO_ROOT)/tao/Object_Proxy_Impl.h \
$(TAO_ROOT)/tao/Object.i \
diff --git a/TAO/tao/PortableServer/MessagingS.cpp b/TAO/tao/PortableServer/MessagingS.cpp
index c1a63a5b197..47c67db376a 100644
--- a/TAO/tao/PortableServer/MessagingS.cpp
+++ b/TAO/tao/PortableServer/MessagingS.cpp
@@ -142,14 +142,14 @@ POA_Messaging::_TAO_ReplyHandler_Strategized_Proxy_Broker::the_TAO_ReplyHandler_
POA_Messaging::_TAO_ReplyHandler_Strategized_Proxy_Broker::_TAO_ReplyHandler_Strategized_Proxy_Broker (void)
{
- for (int i = 0; i < TAO_ORB_Core::COLLOCATION_STRATEGIES_NUM; ++i)
+ for (int i = 0; i < TAO_Collocation_Strategies::CS_LAST; ++i)
this->proxy_cache_[i] = 0;
}
POA_Messaging::_TAO_ReplyHandler_Strategized_Proxy_Broker::~_TAO_ReplyHandler_Strategized_Proxy_Broker (void)
{
- for (int i = 0; i < TAO_ORB_Core::COLLOCATION_STRATEGIES_NUM; ++i)
+ for (int i = 0; i < TAO_Collocation_Strategies::CS_LAST; ++i)
delete this->proxy_cache_[i];
}
@@ -160,7 +160,7 @@ POA_Messaging::_TAO_ReplyHandler_Strategized_Proxy_Broker::select_proxy (
CORBA::Environment &ACE_TRY_ENV
)
{
- TAO_ORB_Core::TAO_Collocation_Strategies strategy =
+ int strategy =
TAO_ORB_Core::collocation_strategy (object);
if (this->proxy_cache_[strategy] != 0)
@@ -175,7 +175,7 @@ POA_Messaging::_TAO_ReplyHandler_Strategized_Proxy_Broker::select_proxy (
void
POA_Messaging::_TAO_ReplyHandler_Strategized_Proxy_Broker::create_proxy (
- TAO_ORB_Core::TAO_Collocation_Strategies strategy,
+ int strategy,
CORBA::Environment &ACE_TRY_ENV
)
{
@@ -185,7 +185,7 @@ POA_Messaging::_TAO_ReplyHandler_Strategized_Proxy_Broker::create_proxy (
{
switch (strategy)
{
- case TAO_ORB_Core::THRU_POA_STRATEGY:
+ case TAO_Collocation_Strategies::CS_THRU_POA_STRATEGY:
ACE_NEW_THROW_EX (
this->proxy_cache_[strategy],
POA_Messaging::_TAO_ReplyHandler_ThruPOA_Proxy_Impl,
@@ -194,7 +194,7 @@ POA_Messaging::_TAO_ReplyHandler_Strategized_Proxy_Broker::create_proxy (
ACE_CHECK;
break;
- case TAO_ORB_Core::DIRECT_STRATEGY:
+ case TAO_Collocation_Strategies::CS_DIRECT_STRATEGY:
ACE_NEW_THROW_EX (
this->proxy_cache_[strategy],
POA_Messaging::_TAO_ReplyHandler_Direct_Proxy_Impl,
@@ -203,7 +203,7 @@ POA_Messaging::_TAO_ReplyHandler_Strategized_Proxy_Broker::create_proxy (
ACE_CHECK;
break;
- case TAO_ORB_Core::REMOTE_STRATEGY:
+ case TAO_Collocation_Strategies::CS_REMOTE_STRATEGY:
default:
ACE_NEW_THROW_EX (
this->proxy_cache_[strategy],
diff --git a/TAO/tao/PortableServer/MessagingS.h b/TAO/tao/PortableServer/MessagingS.h
index 3fad152fc70..da000b2af4b 100644
--- a/TAO/tao/PortableServer/MessagingS.h
+++ b/TAO/tao/PortableServer/MessagingS.h
@@ -123,7 +123,7 @@ TAO_NAMESPACE POA_Messaging
// Helper methods that takes care to create the proxy
// as soon as their use is necessary.
void create_proxy (
- TAO_ORB_Core::TAO_Collocation_Strategies strategy,
+ int collocation_strategy,
CORBA::Environment &ACE_TRY_ENV
);
@@ -133,7 +133,7 @@ TAO_NAMESPACE POA_Messaging
// are totally stateless, and those can be shared by all the
// instances of a given IDL interface type.
::Messaging::_TAO_ReplyHandler_Proxy_Impl
- *proxy_cache_[TAO_ORB_Core::COLLOCATION_STRATEGIES_NUM];
+ *proxy_cache_[TAO_Collocation_Strategies::CS_LAST];
TAO_SYNCH_MUTEX mutex_;
diff --git a/TAO/tao/PortableServer/Object_Adapter.cpp b/TAO/tao/PortableServer/Object_Adapter.cpp
index b872afadde7..6b156ac108e 100644
--- a/TAO/tao/PortableServer/Object_Adapter.cpp
+++ b/TAO/tao/PortableServer/Object_Adapter.cpp
@@ -16,7 +16,8 @@
#include "tao/Stub.h"
#include "tao/Profile.h"
#include "tao/MProfile.h"
-
+#include "tao/debug.h"
+#include "tao/PortableInterceptor.h"
#if !defined (__ACE_INLINE__)
# include "Object_Adapter.i"
@@ -267,7 +268,9 @@ TAO_Object_Adapter::dispatch_servant (const TAO_ObjectKey &key,
Priority_Model_Processing priority_processing (servant_upcall.poa ());
// Set thread's priority.
- priority_processing.pre_invoke (req.service_info (), ACE_TRY_ENV);
+ priority_processing.pre_invoke (req.request_service_context (),
+ req.reply_service_context (),
+ ACE_TRY_ENV);
ACE_CHECK_RETURN (result);
#endif /* TAO_HAS_RT_CORBA == 1 */
@@ -1443,7 +1446,8 @@ TAO_Object_Adapter::Priority_Model_Processing::~Priority_Model_Processing
void
TAO_Object_Adapter::Priority_Model_Processing::pre_invoke (
- IOP::ServiceContextList &service_context_list,
+ TAO_Service_Context &request_service_context,
+ TAO_Service_Context &reply_service_context,
CORBA::Environment &ACE_TRY_ENV)
{
TAO_POA_Policies &poa_policies = this->poa_.policies ();
@@ -1466,37 +1470,35 @@ TAO_Object_Adapter::Priority_Model_Processing::pre_invoke (
// Attempt to extract client-propagated priority from the
// ServiceContextList of the request.
RTCORBA::Priority target_priority;
- int priority_found = 0;
- for (CORBA::ULong i = 0;
- i < service_context_list.length () && !priority_found;
- ++i)
- {
- IOP::ServiceContext &context = service_context_list[i];
-
- if (context.context_id == IOP::RTCorbaPriority)
- {
- TAO_InputCDR cdr (ACE_reinterpret_cast
- (const char*,
- context.context_data.get_buffer ()),
- context.context_data.length ());
-
- CORBA::Boolean byte_order;
- if ((cdr >> ACE_InputCDR::to_boolean (byte_order)) == 0)
- ACE_THROW (CORBA::MARSHAL ());
- cdr.reset_byte_order (ACE_static_cast(int,byte_order));
-
- if ((cdr >> target_priority) == 0)
- ACE_THROW (CORBA::MARSHAL ());
+ const IOP::ServiceContext *context;
- priority_found = 1;
- break;
- }
+ if (request_service_context.get_context (IOP::RTCorbaPriority,
+ &context) == 1)
+ {
+ // Extract the target priority
+ TAO_InputCDR cdr (ACE_reinterpret_cast
+ (const char*,
+ context->context_data.get_buffer ()),
+ context->context_data.length ());
+ CORBA::Boolean byte_order;
+ if ((cdr >> ACE_InputCDR::to_boolean (byte_order)) == 0)
+ ACE_THROW (CORBA::MARSHAL ());
+ cdr.reset_byte_order (ACE_static_cast(int,byte_order));
+
+ if ((cdr >> target_priority) == 0)
+ ACE_THROW (CORBA::MARSHAL ());
+
+ // Save the target priority in the response service
+ // context to propagate back to the client as specified
+ // by the RTCORBA specification.
+ reply_service_context.set_context (*context);
+ }
+ else
+ {
+ // Use default priority if none came in the request. (Request
+ // must have come from a non-RT ORB.)
+ target_priority = poa_policies.server_priority ();
}
-
- // Use default priority if none came in the request. (Request
- // must have come from a non-RT ORB.)
- if (!priority_found)
- target_priority = poa_policies.server_priority ();
// Change the priority of the current thread to the
// client-propagated value for the duration of
diff --git a/TAO/tao/PortableServer/Object_Adapter.h b/TAO/tao/PortableServer/Object_Adapter.h
index a6b1a382782..eab83a3cacc 100644
--- a/TAO/tao/PortableServer/Object_Adapter.h
+++ b/TAO/tao/PortableServer/Object_Adapter.h
@@ -40,6 +40,7 @@
// RTCORBA
#include "tao/RTCORBAC.h"
+#include "tao/Service_Context.h"
// Local Object
#include "tao/LocalObject.h"
@@ -733,7 +734,8 @@ public:
// <post_invoke> method hasn't been called. Unlike <post_invoke>,
// this method cannot propagate exceptions to the user.
- void pre_invoke (IOP::ServiceContextList &service_context_list,
+ void pre_invoke (TAO_Service_Context &request_service_context,
+ TAO_Service_Context &reply_service_context,
CORBA::Environment &ACE_TRY_ENV);
// Checks if target POA supports RTCORBA::CLIENT_PROPAGATED
// PriorityModel. If so, stores the original priority of the
diff --git a/TAO/tao/PortableServer/POA.h b/TAO/tao/PortableServer/POA.h
index 4da455f8abf..16e97f2eaea 100644
--- a/TAO/tao/PortableServer/POA.h
+++ b/TAO/tao/PortableServer/POA.h
@@ -827,6 +827,9 @@ protected:
void cleanup_servant (TAO_Active_Object_Map::Map_Entry *active_object_map_entry,
CORBA::Environment &ACE_TRY_ENV);
+ void deactivate_map_entry (TAO_Active_Object_Map::Map_Entry *active_object_map_entry,
+ CORBA::Environment &ACE_TRY_ENV);
+
CORBA::Object_ptr create_reference_i (const char *intf,
CORBA::Short priority,
CORBA_Environment &ACE_TRY_ENV)
diff --git a/TAO/tao/PortableServer/POA.i b/TAO/tao/PortableServer/POA.i
index baa06a04bbc..8a74c07c228 100644
--- a/TAO/tao/PortableServer/POA.i
+++ b/TAO/tao/PortableServer/POA.i
@@ -34,6 +34,7 @@ TAO_POA_Guard::TAO_POA_Guard (TAO_POA &poa,
// upcall is in progress, wait for it to complete. Unless of
// course, the thread making the non-servant upcall is this thread.
poa.object_adapter ().wait_for_non_servant_upcalls_to_complete (ACE_TRY_ENV);
+ ACE_CHECK;
if (check_for_destruction &&
poa.cleanup_in_progress ())
@@ -311,8 +312,8 @@ TAO_POA::destroy (CORBA::Boolean etherealize_objects,
{
// Lock access for the duration of this transaction.
TAO_POA_Guard poa_guard (*this, ACE_TRY_ENV, 0);
- ACE_UNUSED_ARG (poa_guard);
ACE_CHECK;
+ ACE_UNUSED_ARG (poa_guard);
this->destroy_i (etherealize_objects,
wait_for_completion,
diff --git a/TAO/tao/PortableServer/Servant_Base.i b/TAO/tao/PortableServer/Servant_Base.i
index 3955c3d256a..dcff57157eb 100644
--- a/TAO/tao/PortableServer/Servant_Base.i
+++ b/TAO/tao/PortableServer/Servant_Base.i
@@ -7,7 +7,7 @@ TAO_Servant_Hash::operator () (PortableServer::Servant servant) const
}
ACE_INLINE TAO_Stub *
-TAO_Local_ServantBase::_create_stub (CORBA_Environment &ACE_TRY_ENV)
+TAO_Local_ServantBase::_create_stub (CORBA_Environment & /*ACE_TRY_ENV*/)
{
#if 0
PortableServer::ObjectId_var invalid_oid =
@@ -29,7 +29,7 @@ TAO_Local_ServantBase::_create_stub (CORBA_Environment &ACE_TRY_ENV)
this->_interface_repository_id (),
ACE_TRY_ENV);
#else
- ACE_UNUSED_ARG (ACE_TRY_ENV);
+ // ACE_UNUSED_ARG (ACE_TRY_ENV);
return 0;
#endif
}
diff --git a/TAO/tao/PortableServer/ServerRequestInfo.cpp b/TAO/tao/PortableServer/ServerRequestInfo.cpp
index 8b583fce340..05f48b2e885 100644
--- a/TAO/tao/PortableServer/ServerRequestInfo.cpp
+++ b/TAO/tao/PortableServer/ServerRequestInfo.cpp
@@ -159,34 +159,12 @@ TAO_ServerRequestInfo::get_request_service_context (
CORBA::Environment &ACE_TRY_ENV)
ACE_THROW_SPEC ((CORBA::SystemException))
{
- IOP::ServiceContextList &service_context_list =
- this->server_request_.service_context ().service_info ();
+ TAO_Service_Context &service_context_list =
+ this->server_request_.request_service_context ();
- CORBA::ULong len = service_context_list.length ();
-
- for (CORBA::ULong i = 0; i < len; ++i)
- if (service_context_list[i].context_id == id)
- {
- IOP::ServiceContext *service_context = 0;
- ACE_NEW_THROW_EX (service_context,
- IOP::ServiceContext,
- CORBA::NO_MEMORY (
- CORBA::SystemException::_tao_minor_code (
- TAO_DEFAULT_MINOR_CODE,
- ENOMEM),
- CORBA::COMPLETED_NO));
- ACE_CHECK_RETURN (0);
-
- IOP::ServiceContext_var safe_service_context = service_context;
-
- (*service_context) = service_context_list[i];
-
- return safe_service_context._retn ();
- }
-
- ACE_THROW_RETURN (CORBA::BAD_PARAM (TAO_OMG_VMCID | 23,
- CORBA::COMPLETED_NO),
- 0);
+ return this->get_service_context_i (service_context_list,
+ id,
+ ACE_TRY_ENV);
}
IOP::ServiceContext *
@@ -195,37 +173,50 @@ TAO_ServerRequestInfo::get_reply_service_context (
CORBA::Environment &ACE_TRY_ENV)
ACE_THROW_SPEC ((CORBA::SystemException))
{
- IOP::ServiceContextList &service_context_list =
- this->server_request_.service_context ().service_info ();
-
- CORBA::ULong len = service_context_list.length ();
-
- for (CORBA::ULong i = 0; i < len; ++i)
- if (service_context_list[i].context_id == id)
- {
- IOP::ServiceContext *service_context = 0;
- ACE_NEW_THROW_EX (service_context,
- IOP::ServiceContext,
- CORBA::NO_MEMORY (
- CORBA::SystemException::_tao_minor_code (
- TAO_DEFAULT_MINOR_CODE,
- ENOMEM),
- CORBA::COMPLETED_NO));
- ACE_CHECK_RETURN (0);
+ TAO_Service_Context &service_context_list =
+ this->server_request_.reply_service_context ();
- IOP::ServiceContext_var safe_service_context = service_context;
+ return this->get_service_context_i (service_context_list,
+ id,
+ ACE_TRY_ENV);
+}
- (*service_context) = service_context_list[i];
+IOP::ServiceContext *
+TAO_ServerRequestInfo::get_service_context_i (
+ TAO_Service_Context &service_context_list,
+ IOP::ServiceId id,
+ CORBA::Environment &ACE_TRY_ENV)
+ ACE_THROW_SPEC ((CORBA::SystemException))
+{
+ // Create a new service context to be returned. Assume
+ // success.
+ IOP::ServiceContext *service_context = 0;
+ ACE_NEW_THROW_EX (service_context,
+ IOP::ServiceContext,
+ CORBA::NO_MEMORY (
+ CORBA::SystemException::_tao_minor_code (
+ TAO_DEFAULT_MINOR_CODE,
+ ENOMEM),
+ CORBA::COMPLETED_NO));
+ ACE_CHECK_RETURN (0);
- return safe_service_context._retn ();
- }
+ IOP::ServiceContext_var safe_service_context = service_context;
- ACE_THROW_RETURN (CORBA::BAD_PARAM (TAO_OMG_VMCID | 23,
- CORBA::COMPLETED_NO),
- 0);
+ service_context->context_id = id;
+ if (service_context_list.get_context (*service_context) != 0)
+ {
+ // Found.
+ return safe_service_context._retn ();
+ }
+ else
+ {
+ // Not found.
+ ACE_THROW_RETURN (CORBA::BAD_PARAM (TAO_OMG_VMCID | 23,
+ CORBA::COMPLETED_NO),
+ 0);
+ }
}
-
// Use at own risk. There is no way currently of extracting an
// exception from an Any. This method is in place just to be compliant
// with the spec.
@@ -389,33 +380,15 @@ TAO_ServerRequestInfo::add_reply_service_context (
CORBA::Environment &ACE_TRY_ENV)
ACE_THROW_SPEC ((CORBA::SystemException))
{
- // Copy the service context into the list.
- IOP::ServiceContextList &service_context_list =
- this->server_request_.service_context ().service_info ();
+ // Get the service context from the list
+ TAO_Service_Context &service_context_list =
+ this->server_request_.reply_service_context ();
- CORBA::ULong len = service_context_list.length ();
-
- // First check if a service context with the same ID exists.
- for (CORBA::ULong i = 0; i < len; ++i)
+ if (service_context_list.set_context (service_context,replace) == 0)
{
- if (service_context_list[i].context_id ==
- service_context.context_id)
- {
- if (replace)
- {
- service_context_list[i] = service_context;
- return;
- }
- else
- ACE_THROW (CORBA::BAD_INV_ORDER (TAO_OMG_VMCID | 11,
- CORBA::COMPLETED_NO));
- }
+ ACE_THROW (CORBA::BAD_INV_ORDER (TAO_OMG_VMCID | 11,
+ CORBA::COMPLETED_NO));
}
-
- // No service context with the given ID exists so add one.
- service_context_list.length (len + 1);
-
- service_context_list[len] = service_context;
}
#endif /* TAO_HAS_INTERCEPTORS == 1 */
diff --git a/TAO/tao/PortableServer/ServerRequestInfo.h b/TAO/tao/PortableServer/ServerRequestInfo.h
index 1a06b7aa818..75705012037 100644
--- a/TAO/tao/PortableServer/ServerRequestInfo.h
+++ b/TAO/tao/PortableServer/ServerRequestInfo.h
@@ -31,6 +31,7 @@
#include "tao/LocalObject.h"
#include "tao/StringSeqC.h"
#include "tao/OctetSeqC.h"
+#include "tao/Service_Context.h"
#include "portableserver_export.h"
#if defined(_MSC_VER)
@@ -179,6 +180,14 @@ public:
void forward_reference (CORBA::Object_ptr obj);
protected:
+ /// Helper method to get the request and response service contexts.
+ IOP::ServiceContext *get_service_context_i (
+ TAO_Service_Context &service_context_list,
+ IOP::ServiceId id,
+ CORBA::Environment &ACE_TRY_ENV)
+ ACE_THROW_SPEC ((CORBA::SystemException));
+
+protected:
/// Underlying request object that contains much of the information
/// encapsulated by this ServerRequestInfo class.
diff --git a/TAO/tao/PortableServer/Strategized_Object_Proxy_Broker.cpp b/TAO/tao/PortableServer/Strategized_Object_Proxy_Broker.cpp
index 63c5586cc28..7fc27e57e55 100644
--- a/TAO/tao/PortableServer/Strategized_Object_Proxy_Broker.cpp
+++ b/TAO/tao/PortableServer/Strategized_Object_Proxy_Broker.cpp
@@ -21,7 +21,7 @@ the_tao_strategized_object_proxy_broker (void)
TAO_Strategized_Object_Proxy_Broker::TAO_Strategized_Object_Proxy_Broker (void)
{
for (int i = 0;
- i < TAO_ORB_Core::COLLOCATION_STRATEGIES_NUM;
+ i < TAO_Collocation_Strategies::CS_LAST;
++i)
this->proxy_cache_[i] = 0;
}
@@ -29,7 +29,7 @@ TAO_Strategized_Object_Proxy_Broker::TAO_Strategized_Object_Proxy_Broker (void)
TAO_Strategized_Object_Proxy_Broker::~TAO_Strategized_Object_Proxy_Broker (void)
{
for (int i = 0;
- i < TAO_ORB_Core::COLLOCATION_STRATEGIES_NUM;
+ i < TAO_Collocation_Strategies::CS_LAST;
++i)
delete this->proxy_cache_[i];
}
@@ -38,7 +38,7 @@ TAO_Object_Proxy_Impl &
TAO_Strategized_Object_Proxy_Broker::select_proxy (CORBA::Object_ptr object,
CORBA::Environment &ACE_TRY_ENV)
{
- TAO_ORB_Core::TAO_Collocation_Strategies strategy =
+ int strategy =
TAO_ORB_Core::collocation_strategy (object);
if (this->proxy_cache_[strategy] != 0)
@@ -51,7 +51,7 @@ TAO_Strategized_Object_Proxy_Broker::select_proxy (CORBA::Object_ptr object,
}
void
-TAO_Strategized_Object_Proxy_Broker::create_proxy (TAO_ORB_Core::TAO_Collocation_Strategies strategy,
+TAO_Strategized_Object_Proxy_Broker::create_proxy (int strategy,
CORBA::Environment &ACE_TRY_ENV)
{
ACE_GUARD (TAO_SYNCH_MUTEX,
@@ -62,7 +62,7 @@ TAO_Strategized_Object_Proxy_Broker::create_proxy (TAO_ORB_Core::TAO_Collocation
{
switch (strategy)
{
- case TAO_ORB_Core::THRU_POA_STRATEGY:
+ case TAO_Collocation_Strategies::CS_THRU_POA_STRATEGY:
{
ACE_NEW_THROW_EX (this->proxy_cache_[strategy],
TAO_ThruPOA_Object_Proxy_Impl,
@@ -70,7 +70,7 @@ TAO_Strategized_Object_Proxy_Broker::create_proxy (TAO_ORB_Core::TAO_Collocation
ACE_CHECK;
break;
}
- case TAO_ORB_Core::DIRECT_STRATEGY:
+ case TAO_Collocation_Strategies::CS_DIRECT_STRATEGY:
{
ACE_NEW_THROW_EX (this->proxy_cache_[strategy],
TAO_Direct_Object_Proxy_Impl,
@@ -79,7 +79,7 @@ TAO_Strategized_Object_Proxy_Broker::create_proxy (TAO_ORB_Core::TAO_Collocation
break;
}
default:
- case TAO_ORB_Core::REMOTE_STRATEGY:
+ case TAO_Collocation_Strategies::CS_REMOTE_STRATEGY:
{
ACE_NEW_THROW_EX (this->proxy_cache_[strategy],
TAO_Remote_Object_Proxy_Impl,
diff --git a/TAO/tao/PortableServer/Strategized_Object_Proxy_Broker.h b/TAO/tao/PortableServer/Strategized_Object_Proxy_Broker.h
index 14d0ae0c2a4..93837842a05 100644
--- a/TAO/tao/PortableServer/Strategized_Object_Proxy_Broker.h
+++ b/TAO/tao/PortableServer/Strategized_Object_Proxy_Broker.h
@@ -26,7 +26,7 @@
#include "ace/pre.h"
// -- TAO Include --
-#include "tao/corba.h"
+#include "tao/corbafwd.h"
#include "tao/Object_Proxy_Broker.h"
#include "tao/ORB_Core.h"
@@ -48,13 +48,13 @@ public:
private:
- void create_proxy (TAO_ORB_Core::TAO_Collocation_Strategies strategy,
+ void create_proxy (int collocation_strategy,
CORBA::Environment &ACE_TRY_ENV);
private:
TAO_Object_Proxy_Impl
- *proxy_cache_[TAO_ORB_Core::COLLOCATION_STRATEGIES_NUM];
+ *proxy_cache_[TAO_Collocation_Strategies::CS_LAST];
TAO_SYNCH_MUTEX mutex_;
};
diff --git a/TAO/tao/Strategies/Direct_Priority_Mapping.cpp b/TAO/tao/Strategies/Direct_Priority_Mapping.cpp
index 78db50e7599..b16314573ef 100644
--- a/TAO/tao/Strategies/Direct_Priority_Mapping.cpp
+++ b/TAO/tao/Strategies/Direct_Priority_Mapping.cpp
@@ -5,7 +5,6 @@
#if (TAO_HAS_RT_CORBA == 1)
#include "Direct_Priority_Mapping.h"
-#include "tao/debug.h"
#include "ace/Sched_Params.h"
#if !defined (__ACE_INLINE__)
diff --git a/TAO/tao/Strategies/SHMIOP_Connection_Handler.cpp b/TAO/tao/Strategies/SHMIOP_Connection_Handler.cpp
index 802e34af5d5..14236742606 100644
--- a/TAO/tao/Strategies/SHMIOP_Connection_Handler.cpp
+++ b/TAO/tao/Strategies/SHMIOP_Connection_Handler.cpp
@@ -145,6 +145,9 @@ TAO_SHMIOP_Connection_Handler::activate (long flags,
flags,
THR_BOUND));
+ // Set the id in the transport now that we're active.
+ this->transport ()->id ((int) this->get_handle ());
+
return TAO_SHMIOP_SVC_HANDLER::activate (flags,
n_threads,
force_active,
@@ -192,16 +195,18 @@ TAO_SHMIOP_Connection_Handler::handle_close (ACE_HANDLE handle,
rm));
--this->pending_upcalls_;
- if (this->pending_upcalls_ == 0 &&
- this->is_registered ())
+ if (this->pending_upcalls_ == 0)
{
- // Make sure there are no timers.
- this->reactor ()->cancel_timer (this);
+ if (this->is_registered ())
+ {
+ // Make sure there are no timers.
+ this->reactor ()->cancel_timer (this);
- // Set the flag to indicate that it is no longer registered with
- // the reactor, so that it isn't included in the set that is
- // passed to the reactor on ORB destruction.
- this->is_registered (0);
+ // Set the flag to indicate that it is no longer registered with
+ // the reactor, so that it isn't included in the set that is
+ // passed to the reactor on ORB destruction.
+ this->is_registered (0);
+ }
// Close the handle..
if (this->get_handle () != ACE_INVALID_HANDLE)
diff --git a/TAO/tao/Strategies/SHMIOP_Connector.cpp b/TAO/tao/Strategies/SHMIOP_Connector.cpp
index c8e4c3ad189..4644ff6c698 100644
--- a/TAO/tao/Strategies/SHMIOP_Connector.cpp
+++ b/TAO/tao/Strategies/SHMIOP_Connector.cpp
@@ -158,12 +158,8 @@ TAO_SHMIOP_Connector::connect (TAO_Transport_Descriptor_Interface *desc,
if (TAO_debug_level > 5)
ACE_DEBUG ((LM_DEBUG,
ACE_TEXT ("(%P|%t) SHMIOP_Connector::connect ")
- ACE_TEXT ("got an existing connection \n")));
-
- // We have found a connection and a handler
- svc_handler =
- ACE_dynamic_cast (TAO_SHMIOP_Connection_Handler *,
- base_transport->connection_handler ());
+ ACE_TEXT ("got an existing transport with id %d \n"),
+ base_transport->id ()));
}
else
{
diff --git a/TAO/tao/Strategies/SHMIOP_Transport.cpp b/TAO/tao/Strategies/SHMIOP_Transport.cpp
index bb39b601bb8..0702b07e05f 100644
--- a/TAO/tao/Strategies/SHMIOP_Transport.cpp
+++ b/TAO/tao/Strategies/SHMIOP_Transport.cpp
@@ -55,41 +55,29 @@ TAO_SHMIOP_Transport::~TAO_SHMIOP_Transport (void)
delete this->messaging_object_;
}
-TAO_SHMIOP_SVC_HANDLER *
-TAO_SHMIOP_Transport::service_handler (void)
-{
- return this->connection_handler_;
-}
-
-ACE_HANDLE
-TAO_SHMIOP_Transport::handle (void)
-{
- return this->connection_handler_->get_handle ();
-}
-
ACE_Event_Handler *
-TAO_SHMIOP_Transport::event_handler (void)
+TAO_SHMIOP_Transport::event_handler_i (void)
{
return this->connection_handler_;
}
ssize_t
-TAO_SHMIOP_Transport::send (const ACE_Message_Block *message_block,
- const ACE_Time_Value *max_wait_time,
- size_t *)
+TAO_SHMIOP_Transport::send_i (const ACE_Message_Block *message_block,
+ const ACE_Time_Value *max_wait_time,
+ size_t *)
{
- return this->service_handler ()->peer ().send (message_block,
- max_wait_time);
+ return this->connection_handler_->peer ().send (message_block,
+ max_wait_time);
}
ssize_t
-TAO_SHMIOP_Transport::recv (char *buf,
- size_t len,
- const ACE_Time_Value *max_wait_time)
+TAO_SHMIOP_Transport::recv_i (char *buf,
+ size_t len,
+ const ACE_Time_Value *max_wait_time)
{
- return this->service_handler ()->peer ().recv (buf,
- len,
- max_wait_time);
+ return this->connection_handler_->peer ().recv (buf,
+ len,
+ max_wait_time);
}
@@ -129,7 +117,7 @@ TAO_SHMIOP_Transport::read_process_message (ACE_Time_Value *max_wait_time,
int
-TAO_SHMIOP_Transport::register_handler (void)
+TAO_SHMIOP_Transport::register_handler_i (void)
{
// @@ It seems like this method should go away, the right reactor is
// picked at object creation time.
@@ -193,8 +181,8 @@ TAO_SHMIOP_Transport::send_message (TAO_OutputCDR &stream,
{
if (TAO_debug_level)
ACE_DEBUG ((LM_DEBUG,
- ACE_TEXT ("TAO: (%P|%t|%N|%l) closing conn %d after fault %p\n"),
- this->handle (),
+ ACE_TEXT ("TAO: (%P|%t|%N|%l) closing transport %d after fault %p\n"),
+ this->id (),
ACE_TEXT ("send_message ()\n")));
return -1;
@@ -206,8 +194,8 @@ TAO_SHMIOP_Transport::send_message (TAO_OutputCDR &stream,
if (TAO_debug_level)
ACE_DEBUG ((LM_DEBUG,
ACE_TEXT ("TAO: (%P|%t|%N|%l) send_message () \n")
- ACE_TEXT ("EOF, closing conn %d\n"),
- this->handle()));
+ ACE_TEXT ("EOF, closing transport %d\n"),
+ this->id ()));
return -1;
}
@@ -355,8 +343,8 @@ TAO_SHMIOP_Transport::process_message (void)
{
if (TAO_debug_level > 0)
ACE_ERROR ((LM_ERROR,
- ACE_TEXT ("TAO (%P|%t) : SHMIOP_Client_Transport::")
- ACE_TEXT ("handle_client_input - ")
+ ACE_TEXT ("TAO (%P|%t) : SHMIOP_Transport::")
+ ACE_TEXT ("process_message - ")
ACE_TEXT ("dispatch reply failed\n")));
this->messaging_object_->reset ();
this->tms_->connection_closed ();
@@ -393,15 +381,9 @@ TAO_SHMIOP_Transport::process_message (void)
}
void
-TAO_SHMIOP_Transport::transition_handler_state (void)
+TAO_SHMIOP_Transport::transition_handler_state_i (void)
{
connection_handler_ = 0;
}
-TAO_Connection_Handler*
-TAO_SHMIOP_Transport::connection_handler (void) const
-{
- return connection_handler_;
-}
-
#endif /* TAO_HAS_SHMIOP && TAO_HAS_SHMIOP != 0 */
diff --git a/TAO/tao/Strategies/SHMIOP_Transport.h b/TAO/tao/Strategies/SHMIOP_Transport.h
index 00aa36b4c75..5c6f4e84176 100644
--- a/TAO/tao/Strategies/SHMIOP_Transport.h
+++ b/TAO/tao/Strategies/SHMIOP_Transport.h
@@ -55,24 +55,24 @@ public:
/// Default destructor.
~TAO_SHMIOP_Transport (void);
- /// Return the connection service handler
- TAO_SHMIOP_SVC_HANDLER *service_handler (void);
+protected:
+ /** @name Overridden Template Methods
+ *
+ * These are implementations of template methods declared by TAO_Transport.
+ */
+ //@{
- /// The TAO_Transport methods, please check the documentation in
- /// "tao/Pluggable.h" for more details.
- virtual ACE_HANDLE handle (void);
-
- virtual ACE_Event_Handler *event_handler (void);
+ virtual ACE_Event_Handler *event_handler_i (void);
/// Write the complete Message_Block chain to the connection.
- virtual ssize_t send (const ACE_Message_Block *mblk,
- const ACE_Time_Value *s = 0,
- size_t *bytes_transferred = 0);
+ virtual ssize_t send_i (const ACE_Message_Block *mblk,
+ const ACE_Time_Value *s = 0,
+ size_t *bytes_transferred = 0);
/// Read len bytes from into buf.
- virtual ssize_t recv (char *buf,
- size_t len,
- const ACE_Time_Value *s = 0);
+ virtual ssize_t recv_i (char *buf,
+ size_t len,
+ const ACE_Time_Value *s = 0);
/// Read and process the message from the connection. The processing
/// of the message is done by delegating the work to the underlying
@@ -80,8 +80,13 @@ public:
virtual int read_process_message (ACE_Time_Value *max_time_value = 0,
int block =0);
- virtual int register_handler (void);
+ virtual int register_handler_i (void);
+ /// Method to do whatever it needs to do when the connection
+ /// handler is being closed and destroyed.
+ virtual void transition_handler_state_i (void);
+
+public:
/// @@TODO: These methods IMHO should have more meaningful
/// names. The names seem to indicate nothing.
virtual int send_request (TAO_Stub *stub,
@@ -122,20 +127,13 @@ public:
/// signalling.
virtual int reactor_signalling (void);
- /// Method to do whatever it needs to do when the connection
- /// handler is being closed and destroyed.
- virtual void transition_handler_state (void);
-
- // Access the connection handler
- virtual TAO_Connection_Handler* connection_handler (void) const;
+ //@}
private:
-
/// Process the message that we have read
int process_message (void);
private:
-
/// The connection service handler used for accessing lower layer
/// communication protocols.
TAO_SHMIOP_Connection_Handler *connection_handler_;
diff --git a/TAO/tao/Strategies/UIOP_Connection_Handler.cpp b/TAO/tao/Strategies/UIOP_Connection_Handler.cpp
index 37c252530ca..378855bbadb 100644
--- a/TAO/tao/Strategies/UIOP_Connection_Handler.cpp
+++ b/TAO/tao/Strategies/UIOP_Connection_Handler.cpp
@@ -127,6 +127,9 @@ TAO_UIOP_Connection_Handler::activate (long flags,
flags,
THR_BOUND));
+ // Set the id in the transport now that we're active.
+ this->transport ()->id ((int) this->get_handle ());
+
return TAO_UIOP_SVC_HANDLER::activate (flags,
n_threads,
force_active,
@@ -174,16 +177,18 @@ TAO_UIOP_Connection_Handler::handle_close (ACE_HANDLE handle,
rm));
--this->pending_upcalls_;
- if (this->pending_upcalls_ == 0 &&
- this->is_registered ())
+ if (this->pending_upcalls_ == 0)
{
- // Make sure there are no timers.
- this->reactor ()->cancel_timer (this);
+ if (this->is_registered ())
+ {
+ // Make sure there are no timers.
+ this->reactor ()->cancel_timer (this);
- // Set the flag to indicate that it is no longer registered with
- // the reactor, so that it isn't included in the set that is
- // passed to the reactor on ORB destruction.
- this->is_registered (0);
+ // Set the flag to indicate that it is no longer registered with
+ // the reactor, so that it isn't included in the set that is
+ // passed to the reactor on ORB destruction.
+ this->is_registered (0);
+ }
// Close the handle..
if (this->get_handle () != ACE_INVALID_HANDLE)
diff --git a/TAO/tao/Strategies/UIOP_Connector.cpp b/TAO/tao/Strategies/UIOP_Connector.cpp
index b07795db20f..61c328b3863 100644
--- a/TAO/tao/Strategies/UIOP_Connector.cpp
+++ b/TAO/tao/Strategies/UIOP_Connector.cpp
@@ -165,12 +165,8 @@ TAO_UIOP_Connector::connect (TAO_Transport_Descriptor_Interface *desc,
if (TAO_debug_level > 5)
ACE_DEBUG ((LM_DEBUG,
ACE_TEXT ("(%P|%t) UIOP_Connector::connect ")
- ACE_TEXT ("got an existing connection \n")));
-
- // We have found a connection and a handler
- svc_handler =
- ACE_dynamic_cast (TAO_UIOP_Connection_Handler *,
- base_transport->connection_handler ());
+ ACE_TEXT ("got an existing transport with id %d \n"),
+ base_transport->id ()));
}
else
{
diff --git a/TAO/tao/Strategies/UIOP_Endpoint.cpp b/TAO/tao/Strategies/UIOP_Endpoint.cpp
index 32a743fc980..2114bf893da 100644
--- a/TAO/tao/Strategies/UIOP_Endpoint.cpp
+++ b/TAO/tao/Strategies/UIOP_Endpoint.cpp
@@ -7,8 +7,6 @@
#if TAO_HAS_UIOP == 1
-#include "tao/debug.h"
-
ACE_RCSID(Strategies, UIOP_Endpoint, "$Id$")
#if !defined (__ACE_INLINE__)
diff --git a/TAO/tao/Strategies/UIOP_Transport.cpp b/TAO/tao/Strategies/UIOP_Transport.cpp
index 29f67574369..5a438d9f994 100644
--- a/TAO/tao/Strategies/UIOP_Transport.cpp
+++ b/TAO/tao/Strategies/UIOP_Transport.cpp
@@ -32,9 +32,9 @@ TAO_UIOP_Transport::TAO_UIOP_Transport (TAO_UIOP_Connection_Handler *handler,
TAO_ORB_Core *orb_core,
CORBA::Boolean flag)
: TAO_Transport (TAO_TAG_UIOP_PROFILE,
- orb_core),
- connection_handler_ (handler),
- messaging_object_ (0)
+ orb_core)
+ , connection_handler_ (handler)
+ , messaging_object_ (0)
{
if (flag)
{
@@ -55,43 +55,31 @@ TAO_UIOP_Transport::~TAO_UIOP_Transport (void)
delete this->messaging_object_;
}
-TAO_UIOP_SVC_HANDLER *
-TAO_UIOP_Transport::service_handler (void)
-{
- return this->connection_handler_;
-}
-
-ACE_HANDLE
-TAO_UIOP_Transport::handle (void)
-{
- return this->connection_handler_->get_handle ();
-}
-
ACE_Event_Handler *
-TAO_UIOP_Transport::event_handler (void)
+TAO_UIOP_Transport::event_handler_i (void)
{
return this->connection_handler_;
}
ssize_t
-TAO_UIOP_Transport::send (const ACE_Message_Block *message_block,
- const ACE_Time_Value *max_wait_time,
- size_t *bytes_transferred)
+TAO_UIOP_Transport::send_i (const ACE_Message_Block *message_block,
+ const ACE_Time_Value *max_wait_time,
+ size_t *bytes_transferred)
{
- return ACE::send_n (this->handle (),
+ return ACE::send_n (this->connection_handler_->get_handle (),
message_block,
max_wait_time,
bytes_transferred);
}
ssize_t
-TAO_UIOP_Transport::recv (char *buf,
- size_t len,
- const ACE_Time_Value *max_wait_time)
+TAO_UIOP_Transport::recv_i (char *buf,
+ size_t len,
+ const ACE_Time_Value *max_wait_time)
{
- return this->service_handler ()->peer ().recv (buf,
- len,
- max_wait_time);
+ return this->connection_handler_->peer ().recv (buf,
+ len,
+ max_wait_time);
}
int
@@ -130,7 +118,7 @@ TAO_UIOP_Transport::read_process_message (ACE_Time_Value *max_wait_time,
int
-TAO_UIOP_Transport::register_handler (void)
+TAO_UIOP_Transport::register_handler_i (void)
{
// @@ It seems like this method should go away, the right reactor is
// picked at object creation time.
@@ -194,8 +182,8 @@ TAO_UIOP_Transport::send_message (TAO_OutputCDR &stream,
{
if (TAO_debug_level)
ACE_DEBUG ((LM_DEBUG,
- ACE_TEXT ("TAO: (%P|%t|%N|%l) closing conn %d after fault %p\n"),
- this->handle (),
+ ACE_TEXT ("TAO: (%P|%t|%N|%l) closing transport %d after fault %p\n"),
+ this->id (),
ACE_TEXT ("send_message ()\n")));
return -1;
@@ -207,8 +195,8 @@ TAO_UIOP_Transport::send_message (TAO_OutputCDR &stream,
if (TAO_debug_level)
ACE_DEBUG ((LM_DEBUG,
ACE_TEXT ("TAO: (%P|%t|%N|%l) send_message () \n")
- ACE_TEXT ("EOF, closing conn %d\n"),
- this->handle()));
+ ACE_TEXT ("EOF, closing transport %d\n"),
+ this->id ()));
return -1;
}
@@ -350,8 +338,8 @@ TAO_UIOP_Transport::process_message (void)
{
if (TAO_debug_level > 0)
ACE_ERROR ((LM_ERROR,
- ACE_TEXT ("TAO (%P|%t) : UIOP_Client_Transport::")
- ACE_TEXT ("handle_client_input - ")
+ ACE_TEXT ("TAO (%P|%t) : UIOP_Transport::")
+ ACE_TEXT ("process_message - ")
ACE_TEXT ("dispatch reply failed\n")));
this->messaging_object_->reset ();
this->tms_->connection_closed ();
@@ -387,15 +375,9 @@ TAO_UIOP_Transport::process_message (void)
}
void
-TAO_UIOP_Transport::transition_handler_state (void)
+TAO_UIOP_Transport::transition_handler_state_i (void)
{
connection_handler_ = 0;
}
-TAO_Connection_Handler*
-TAO_UIOP_Transport::connection_handler (void) const
-{
- return connection_handler_;
-}
-
#endif /* TAO_HAS_UIOP */
diff --git a/TAO/tao/Strategies/UIOP_Transport.h b/TAO/tao/Strategies/UIOP_Transport.h
index b9b9b172fc1..b95eeec6e89 100644
--- a/TAO/tao/Strategies/UIOP_Transport.h
+++ b/TAO/tao/Strategies/UIOP_Transport.h
@@ -60,24 +60,24 @@ public:
/// Default destructor.
~TAO_UIOP_Transport (void);
- /// Return the connection service handler
- TAO_UIOP_SVC_HANDLER *service_handler (void);
+protected:
+ /** @name Overridden Template Methods
+ *
+ * These are implementations of template methods declared by TAO_Transport.
+ */
+ //@{
- /// The TAO_Transport methods, please check the documentation in
- /// "tao/Pluggable.h" for more details.
- virtual ACE_HANDLE handle (void);
-
- virtual ACE_Event_Handler *event_handler (void);
+ virtual ACE_Event_Handler *event_handler_i (void);
/// Write the complete Message_Block chain to the connection.
- virtual ssize_t send (const ACE_Message_Block *mblk,
- const ACE_Time_Value *s = 0,
- size_t *bytes_transferred = 0);
+ virtual ssize_t send_i (const ACE_Message_Block *mblk,
+ const ACE_Time_Value *s = 0,
+ size_t *bytes_transferred = 0);
/// Read len bytes from into buf.
- virtual ssize_t recv (char *buf,
- size_t len,
- const ACE_Time_Value *s = 0);
+ virtual ssize_t recv_i (char *buf,
+ size_t len,
+ const ACE_Time_Value *s = 0);
/// Read and process the message from the connection. The processing
/// of the message is done by delegating the work to the underlying
@@ -85,8 +85,13 @@ public:
virtual int read_process_message (ACE_Time_Value *max_time_value = 0,
int block =0);
- virtual int register_handler (void);
+ virtual int register_handler_i (void);
+
+ /// Method to do whatever it needs to do when the connection
+ /// handler is being closed and destroyed.
+ virtual void transition_handler_state_i (void);
+public:
/// @@TODO: These methods IMHO should have more meaningful
/// names. The names seem to indicate nothing.
virtual int send_request (TAO_Stub *stub,
@@ -123,12 +128,7 @@ public:
virtual int messaging_init (CORBA::Octet major,
CORBA::Octet minor);
- /// Method to do whatever it needs to do when the connection
- /// handler is being closed and destroyed.
- virtual void transition_handler_state (void);
-
- // Access the connection handler
- virtual TAO_Connection_Handler* connection_handler (void) const;
+ //@}
private:
diff --git a/TAO/tao/Strategies/advanced_resource.cpp b/TAO/tao/Strategies/advanced_resource.cpp
index cda77541196..c4597341d59 100644
--- a/TAO/tao/Strategies/advanced_resource.cpp
+++ b/TAO/tao/Strategies/advanced_resource.cpp
@@ -282,7 +282,7 @@ TAO_Advanced_Resource_Factory::init_protocol_factories (void)
if (protocol_factory == 0)
{
- if (TAO_orbdebug)
+ if (TAO_debug_level > 0)
ACE_ERROR ((LM_WARNING,
"(%P|%t) WARNING - No %s found in Service Repository."
" Using default instance.\n",
@@ -345,7 +345,7 @@ TAO_Advanced_Resource_Factory::init_protocol_factories (void)
if (protocol_factory == 0)
{
- if (TAO_orbdebug)
+ if (TAO_debug_level > 0)
ACE_ERROR ((LM_WARNING,
"(%P|%t) WARNING - No %s found in Service Repository."
" Using default instance.\n",
diff --git a/TAO/tao/PortableServer/POA.cpp b/TAO/tao/PortableServer/POA.cpp
index 766ca09eab0..40489d2d51b 100644
--- a/TAO/tao/PortableServer/POA.cpp
+++ b/TAO/tao/PortableServer/POA.cpp
@@ -20,7 +20,7 @@
#include "tao/Acceptor_Registry.h"
#include "tao/RT_Policy_i.h"
-#include "tao/BiDir_Policy_i.h"
+
#include "Default_Acceptor_Filter.h"
#include "RT_Acceptor_Filters.h"
@@ -69,6 +69,7 @@ public:
ACE_THROW_SPEC (())
{
this->orb_->shutdown (0, ACE_TRY_ENV);
+ ACE_CHECK;
}
private:
CORBA::ORB_ptr orb_;
@@ -1157,9 +1158,10 @@ TAO_POA::deactivate_all_objects_i (CORBA::Boolean etherealize_objects,
// invoke operations on the POA will receive the OBJECT_NOT_EXIST
// exception.
- // We must copy the user ids into a separate place since we cannot
- // remove entries while iterating through the map.
- ACE_Array<PortableServer::ObjectId> ids (this->active_object_map ().current_size ());
+ // We must copy the map entries into a separate place since we
+ // cannot remove entries while iterating through the map.
+ ACE_Array_Base<TAO_Active_Object_Map::Map_Entry *> map_entries
+ (this->active_object_map ().current_size ());
size_t counter = 0;
TAO_Active_Object_Map::user_id_map::iterator end
@@ -1175,7 +1177,7 @@ TAO_POA::deactivate_all_objects_i (CORBA::Boolean etherealize_objects,
if (!active_object_map_entry->deactivated_)
{
- ids[counter] = active_object_map_entry->user_id_;
+ map_entries[counter] = active_object_map_entry;
++counter;
}
}
@@ -1184,8 +1186,8 @@ TAO_POA::deactivate_all_objects_i (CORBA::Boolean etherealize_objects,
i < counter;
++i)
{
- this->deactivate_object_i (ids[i],
- ACE_TRY_ENV);
+ this->deactivate_map_entry (map_entries[i],
+ ACE_TRY_ENV);
ACE_CHECK;
}
}
@@ -1215,6 +1217,15 @@ TAO_POA::deactivate_object_i (const PortableServer::ObjectId &id,
ACE_THROW (PortableServer::POA::ObjectNotActive ());
}
+ this->deactivate_map_entry (active_object_map_entry,
+ ACE_TRY_ENV);
+ ACE_CHECK;
+}
+
+void
+TAO_POA::deactivate_map_entry (TAO_Active_Object_Map::Map_Entry *active_object_map_entry,
+ CORBA::Environment &ACE_TRY_ENV)
+{
// Decrement the reference count.
CORBA::UShort new_count = --active_object_map_entry->reference_count_;
@@ -3884,21 +3895,16 @@ TAO_POA_Policies::parse_policy (const CORBA::Policy_ptr policy,
#endif /* TAO_HAS_RT_CORBA == 1 */
- // Bidirectional policy. If we have a BiDirectional policy, we set a
- // flag in the ORB_Core for use by the ORB
+ // Check whether we have a BiDirectional policy set. Call the
+ // ORB_Core to do the checking for us
+ int retval = this->orb_core_.parse_bidir_policy (policy,
+ ACE_TRY_ENV);
- BiDirPolicy::BidirectionalPolicy_var bidir_policy
- = BiDirPolicy::BidirectionalPolicy::_narrow (policy,
- ACE_TRY_ENV);
ACE_CHECK;
- if (!CORBA::is_nil (bidir_policy.in ()))
- {
- // Set the flag in the ORB_Core
- if (bidir_policy->value () == BiDirPolicy::BOTH)
- this->orb_core_.bidir_giop_policy (1);
- return;
- }
+ // The policy has been successfully parsed, so return
+ if (retval)
+ return;
ACE_THROW (PortableServer::POA::InvalidPolicy ());
}
@@ -4134,52 +4140,73 @@ TAO_POA::key_to_stub_i (const TAO_ObjectKey &key,
TAO_Stub *data = 0;
- // If POA has RTCORBA::SERVER_DECLARED priority model,
- // each object can potentially have a different priority.
- // To preserve correctness with multithreading applications, a
- // separate filter must be used for each object. Here we allocate a
- // filter of the stack, if necessary.
- if (this->policies ().priority_model ()
- == TAO_POA_Policies::SERVER_DECLARED
- && this->policies ().server_priority () != priority)
- {
+ // If the POA has RTCORBA::SERVER_DECLARED priority model
+ // then regardless of the fact that there are or that there
+ // are not bands then we need to pass only one endpoint that
+ // is either the one associated to the bands to which the
+ // server belongs, or the one associated to the server priority.
+ //
+ // If the POA has RTCORBA::CLIENT_EXPOSED, than all endpoints
+ // should be passed.
#if (TAO_HAS_RT_CORBA == 1)
+
+ if (this->policies ().priority_model ()
+ == TAO_POA_Policies::SERVER_DECLARED)
+ {
if (this->policies ().priority_bands () != 0)
{
- TAO_Priority_Acceptor_Filter
+ TAO_Bands_Acceptor_Filter
filter (this->policies ().server_protocol ()->protocols_rep (),
- priority);
+ this->policies ().priority_bands ()->priority_bands_rep());
data = this->orb_core_.create_stub_object (key,
type_id,
client_exposed_policies._retn (),
&filter,
ACE_TRY_ENV);
+ ACE_CHECK_RETURN (0);
}
-
else
{
+ RTCORBA::Priority object_priority =
+ this->policies ().server_priority () > priority ? this->policies ().server_priority () : priority;
+ TAO_Priority_Acceptor_Filter filter (this->policies ().server_protocol ()->protocols_rep (),
+ object_priority);
+
data = this->orb_core_.create_stub_object (key,
type_id,
client_exposed_policies._retn (),
- this->acceptor_filter_,
+ &filter,
ACE_TRY_ENV);
ACE_CHECK_RETURN (0);
}
-#endif /* TAO_HAS_RT_CORBA == 1 */
}
- else
+ else if (this->policies ().priority_model ()
+ == TAO_POA_Policies::CLIENT_PROPAGATED)
{
+ TAO_Server_Protocol_Acceptor_Filter filter ((this->policies ().server_protocol ()->protocols_rep ()));
data = this->orb_core_.create_stub_object (key,
type_id,
client_exposed_policies._retn (),
- this->acceptor_filter_,
+ &filter,
ACE_TRY_ENV);
ACE_CHECK_RETURN (0);
}
+#else /* NON-RT-CORBA Section */
+
+ data = this->orb_core_.create_stub_object (key,
+ type_id,
+ client_exposed_policies._retn (),
+ this->acceptor_filter_,
+ ACE_TRY_ENV);
+ ACE_CHECK_RETURN (0);
+
+#endif /* TAO_HAS_RT_CORBA */
+
+
return data;
}
@@ -4376,8 +4403,8 @@ TAO_POA::imr_notify_shutdown (void)
#endif /* TAO_HAS_MINIMUM_CORBA */
#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
-template class ACE_Array<PortableServer::ObjectId>;
-template class ACE_Array_Base<PortableServer::ObjectId>;
+
+template class ACE_Array_Base<TAO_Active_Object_Map::Map_Entry *>;
//template class ACE_Auto_Basic_Ptr<TAO_Active_Object_Map_Iterator_Impl>;
template class ACE_Auto_Basic_Ptr<TAO_Active_Object_Map>;
@@ -4399,8 +4426,7 @@ template class ACE_Node<TAO_POA *>;
#elif defined (ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
-#pragma instantiate ACE_Array<PortableServer::ObjectId>
-#pragma instantiate ACE_Array_Base<PortableServer::ObjectId>
+#pragma instantiate ACE_Array_Base<TAO_Active_Object_Map::Map_Entry *>
//#pragma instantiate ACE_Auto_Basic_Ptr<TAO_Active_Object_Map_Iterator_Impl>
#pragma instantiate ACE_Auto_Basic_Ptr<TAO_Active_Object_Map>